# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'u2dplot.ui'
#
# Created: Tue Mar 16 11:01:38 2021
#      by: pyside-uic 0.2.15 running on PySide 1.2.2
#
# WARNING! All changes made in this file will be lost!

from PySide import QtCore, QtGui

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(800, 800)
        font = QtGui.QFont()
        font.setPointSize(12)
        MainWindow.setFont(font)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/ugao_icon.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        MainWindow.setWindowIcon(icon)
        self.centralwidget = QtGui.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout = QtGui.QVBoxLayout(self.centralwidget)
        self.verticalLayout.setObjectName("verticalLayout")
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtGui.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 800, 21))
        font = QtGui.QFont()
        font.setFamily("MS UI Gothic")
        font.setWeight(75)
        font.setBold(True)
        self.menubar.setFont(font)
        self.menubar.setDefaultUp(False)
        self.menubar.setObjectName("menubar")
        self.menuFile = QtGui.QMenu(self.menubar)
        self.menuFile.setObjectName("menuFile")
        self.menuEdit = QtGui.QMenu(self.menubar)
        self.menuEdit.setObjectName("menuEdit")
        self.menuView = QtGui.QMenu(self.menubar)
        self.menuView.setObjectName("menuView")
        self.menuAnalyze = QtGui.QMenu(self.menubar)
        self.menuAnalyze.setObjectName("menuAnalyze")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtGui.QStatusBar(MainWindow)
        font = QtGui.QFont()
        font.setFamily("MS UI Gothic")
        font.setWeight(75)
        font.setBold(True)
        self.statusbar.setFont(font)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.actionOpen = QtGui.QAction(MainWindow)
        self.actionOpen.setObjectName("actionOpen")
        self.actionSave_as_Binary = QtGui.QAction(MainWindow)
        self.actionSave_as_Binary.setObjectName("actionSave_as_Binary")
        self.actionSave_as_Text = QtGui.QAction(MainWindow)
        self.actionSave_as_Text.setObjectName("actionSave_as_Text")
        self.actionExit = QtGui.QAction(MainWindow)
        self.actionExit.setObjectName("actionExit")
        self.actionSet_View_Parameters = QtGui.QAction(MainWindow)
        self.actionSet_View_Parameters.setObjectName("actionSet_View_Parameters")
        self.actionSet_Regions = QtGui.QAction(MainWindow)
        self.actionSet_Regions.setEnabled(True)
        self.actionSet_Regions.setObjectName("actionSet_Regions")
        self.actionOpen_View_Parameters = QtGui.QAction(MainWindow)
        self.actionOpen_View_Parameters.setObjectName("actionOpen_View_Parameters")
        self.actionSave_View_Parameters = QtGui.QAction(MainWindow)
        self.actionSave_View_Parameters.setObjectName("actionSave_View_Parameters")
        self.actionShow_All_Regions = QtGui.QAction(MainWindow)
        self.actionShow_All_Regions.setObjectName("actionShow_All_Regions")
        self.actionHide_All_Regions = QtGui.QAction(MainWindow)
        self.actionHide_All_Regions.setObjectName("actionHide_All_Regions")
        self.actionSlice_setting = QtGui.QAction(MainWindow)
        self.actionSlice_setting.setObjectName("actionSlice_setting")
        self.menuFile.addAction(self.actionOpen)
        self.menuFile.addAction(self.actionSave_as_Binary)
        self.menuFile.addAction(self.actionSave_as_Text)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionExit)
        self.menuEdit.addAction(self.actionSet_View_Parameters)
        self.menuEdit.addAction(self.actionSet_Regions)
        self.menuEdit.addAction(self.actionSlice_setting)
        self.menuEdit.addSeparator()
        self.menuEdit.addAction(self.actionOpen_View_Parameters)
        self.menuEdit.addAction(self.actionSave_View_Parameters)
        self.menuView.addAction(self.actionShow_All_Regions)
        self.menuView.addAction(self.actionHide_All_Regions)
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuEdit.menuAction())
        self.menubar.addAction(self.menuView.menuAction())
        self.menubar.addAction(self.menuAnalyze.menuAction())

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "MainWindow", None, QtGui.QApplication.UnicodeUTF8))
        self.menuFile.setTitle(QtGui.QApplication.translate("MainWindow", "File", None, QtGui.QApplication.UnicodeUTF8))
        self.menuEdit.setTitle(QtGui.QApplication.translate("MainWindow", "Edit", None, QtGui.QApplication.UnicodeUTF8))
        self.menuView.setTitle(QtGui.QApplication.translate("MainWindow", "View", None, QtGui.QApplication.UnicodeUTF8))
        self.menuAnalyze.setTitle(QtGui.QApplication.translate("MainWindow", "Analyze", None, QtGui.QApplication.UnicodeUTF8))
        self.actionOpen.setText(QtGui.QApplication.translate("MainWindow", "Open", None, QtGui.QApplication.UnicodeUTF8))
        self.actionOpen.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+O", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSave_as_Binary.setText(QtGui.QApplication.translate("MainWindow", "Save as Binary", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSave_as_Text.setText(QtGui.QApplication.translate("MainWindow", "Save as Text", None, QtGui.QApplication.UnicodeUTF8))
        self.actionExit.setText(QtGui.QApplication.translate("MainWindow", "Exit", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSet_View_Parameters.setText(QtGui.QApplication.translate("MainWindow", "Set View Parameters", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSet_View_Parameters.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+Shift+V", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSet_Regions.setText(QtGui.QApplication.translate("MainWindow", "Set Regions", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSet_Regions.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+Shift+R", None, QtGui.QApplication.UnicodeUTF8))
        self.actionOpen_View_Parameters.setText(QtGui.QApplication.translate("MainWindow", "Open View Parameters", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSave_View_Parameters.setText(QtGui.QApplication.translate("MainWindow", "Save View Parameters", None, QtGui.QApplication.UnicodeUTF8))
        self.actionShow_All_Regions.setText(QtGui.QApplication.translate("MainWindow", "Show All Regions", None, QtGui.QApplication.UnicodeUTF8))
        self.actionHide_All_Regions.setText(QtGui.QApplication.translate("MainWindow", "Hide All Regions", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSlice_setting.setText(QtGui.QApplication.translate("MainWindow", "Set Slice Regions", None, QtGui.QApplication.UnicodeUTF8))

try:
    import u2dplot_rc
except:
    import uGao.u2dplot_rc

# Form implementation generated from reading ui file 'dg_overplot.ui'
#
# Created: Tue Mar 16 11:01:38 2021
#      by: pyside-uic 0.2.15 running on PySide 1.2.2
#
# WARNING! All changes made in this file will be lost!


class Ui_DgOverPlot(object):
    def setupUi(self, DgOverPlot):
        DgOverPlot.setObjectName("DgOverPlot")
        DgOverPlot.resize(592, 320)
        self.btAdd = QtGui.QPushButton(DgOverPlot)
        self.btAdd.setGeometry(QtCore.QRect(500, 20, 81, 27))
        self.btAdd.setObjectName("btAdd")
        self.btRemove = QtGui.QPushButton(DgOverPlot)
        self.btRemove.setGeometry(QtCore.QRect(500, 70, 81, 27))
        self.btRemove.setObjectName("btRemove")
        self.btClose = QtGui.QPushButton(DgOverPlot)
        self.btClose.setGeometry(QtCore.QRect(500, 290, 81, 27))
        self.btClose.setObjectName("btClose")

        self.retranslateUi(DgOverPlot)
        QtCore.QMetaObject.connectSlotsByName(DgOverPlot)

    def retranslateUi(self, DgOverPlot):
        DgOverPlot.setWindowTitle(QtGui.QApplication.translate("DgOverPlot", "Dialog", None, QtGui.QApplication.UnicodeUTF8))
        self.btAdd.setText(QtGui.QApplication.translate("DgOverPlot", "Add File ...", None, QtGui.QApplication.UnicodeUTF8))
        self.btRemove.setText(QtGui.QApplication.translate("DgOverPlot", "Remove", None, QtGui.QApplication.UnicodeUTF8))
        self.btClose.setText(QtGui.QApplication.translate("DgOverPlot", "Close", None, QtGui.QApplication.UnicodeUTF8))


# Form implementation generated from reading ui file 'dg_region.ui'
#
# Created: Tue Mar 16 11:01:39 2021
#      by: pyside-uic 0.2.15 running on PySide 1.2.2
#
# WARNING! All changes made in this file will be lost!


class Ui_DlgRegion(object):
    def setupUi(self, DlgRegion):
        DlgRegion.setObjectName("DlgRegion")
        DlgRegion.resize(600, 673)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/ugao_icon.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        DlgRegion.setWindowIcon(icon)
        self.tabRegion = QtGui.QTabWidget(DlgRegion)
        self.tabRegion.setGeometry(QtCore.QRect(10, 10, 501, 145))
        self.tabRegion.setTabPosition(QtGui.QTabWidget.North)
        self.tabRegion.setTabShape(QtGui.QTabWidget.Rounded)
        self.tabRegion.setIconSize(QtCore.QSize(16, 16))
        self.tabRegion.setElideMode(QtCore.Qt.ElideNone)
        self.tabRegion.setUsesScrollButtons(False)
        self.tabRegion.setDocumentMode(False)
        self.tabRegion.setTabsClosable(False)
        self.tabRegion.setMovable(False)
        self.tabRegion.setObjectName("tabRegion")
        self.tabPoint = QtGui.QWidget()
        self.tabPoint.setObjectName("tabPoint")
        self.gridLayout_7 = QtGui.QGridLayout(self.tabPoint)
        self.gridLayout_7.setObjectName("gridLayout_7")
        spacerItem = QtGui.QSpacerItem(26, 20, QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Minimum)
        self.gridLayout_7.addItem(spacerItem, 0, 1, 1, 1)
        self.rs_label0_10 = QtGui.QLabel(self.tabPoint)
        self.rs_label0_10.setMinimumSize(QtCore.QSize(40, 0))
        self.rs_label0_10.setObjectName("rs_label0_10")
        self.gridLayout_7.addWidget(self.rs_label0_10, 0, 2, 1, 1)
        self.point_tx0 = QtGui.QLineEdit(self.tabPoint)
        self.point_tx0.setObjectName("point_tx0")
        self.gridLayout_7.addWidget(self.point_tx0, 0, 3, 1, 1)
        self.point_label0_18 = QtGui.QLabel(self.tabPoint)
        self.point_label0_18.setObjectName("point_label0_18")
        self.gridLayout_7.addWidget(self.point_label0_18, 0, 4, 1, 1)
        self.point_tx1 = QtGui.QLineEdit(self.tabPoint)
        self.point_tx1.setText("")
        self.point_tx1.setObjectName("point_tx1")
        self.gridLayout_7.addWidget(self.point_tx1, 0, 5, 1, 1)
        spacerItem1 = QtGui.QSpacerItem(48, 20, QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Minimum)
        self.gridLayout_7.addItem(spacerItem1, 1, 0, 1, 1)
        spacerItem2 = QtGui.QSpacerItem(26, 20, QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Minimum)
        self.gridLayout_7.addItem(spacerItem2, 2, 1, 1, 1)
        self.tabRegion.addTab(self.tabPoint, "")
        self.tabLine = QtGui.QWidget()
        self.tabLine.setObjectName("tabLine")
        self.gridLayout_5 = QtGui.QGridLayout(self.tabLine)
        self.gridLayout_5.setObjectName("gridLayout_5")
        spacerItem3 = QtGui.QSpacerItem(26, 20, QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Minimum)
        self.gridLayout_5.addItem(spacerItem3, 0, 1, 1, 1)
        self.rs_label0_5 = QtGui.QLabel(self.tabLine)
        self.rs_label0_5.setObjectName("rs_label0_5")
        self.gridLayout_5.addWidget(self.rs_label0_5, 0, 2, 1, 1)
        self.line_tx0 = QtGui.QLineEdit(self.tabLine)
        self.line_tx0.setObjectName("line_tx0")
        self.gridLayout_5.addWidget(self.line_tx0, 0, 3, 1, 1)
        self.point_label0_14 = QtGui.QLabel(self.tabLine)
        self.point_label0_14.setObjectName("point_label0_14")
        self.gridLayout_5.addWidget(self.point_label0_14, 0, 4, 1, 1)
        self.line_tx1 = QtGui.QLineEdit(self.tabLine)
        self.line_tx1.setText("")
        self.line_tx1.setObjectName("line_tx1")
        self.gridLayout_5.addWidget(self.line_tx1, 0, 5, 1, 1)
        self.line_tx2 = QtGui.QLineEdit(self.tabLine)
        self.line_tx2.setObjectName("line_tx2")
        self.gridLayout_5.addWidget(self.line_tx2, 1, 3, 1, 1)
        self.line_tx3 = QtGui.QLineEdit(self.tabLine)
        self.line_tx3.setObjectName("line_tx3")
        self.gridLayout_5.addWidget(self.line_tx3, 1, 5, 1, 1)
        spacerItem4 = QtGui.QSpacerItem(26, 20, QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Minimum)
        self.gridLayout_5.addItem(spacerItem4, 2, 1, 1, 1)
        self.line_tx4 = QtGui.QLineEdit(self.tabLine)
        self.line_tx4.setObjectName("line_tx4")
        self.gridLayout_5.addWidget(self.line_tx4, 2, 3, 1, 1)
        spacerItem5 = QtGui.QSpacerItem(48, 20, QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Minimum)
        self.gridLayout_5.addItem(spacerItem5, 1, 0, 1, 1)
        self.rs_label0_6 = QtGui.QLabel(self.tabLine)
        self.rs_label0_6.setObjectName("rs_label0_6")
        self.gridLayout_5.addWidget(self.rs_label0_6, 1, 2, 1, 1)
        self.point_label0_16 = QtGui.QLabel(self.tabLine)
        self.point_label0_16.setObjectName("point_label0_16")
        self.gridLayout_5.addWidget(self.point_label0_16, 1, 4, 1, 1)
        self.label_15 = QtGui.QLabel(self.tabLine)
        self.label_15.setMinimumSize(QtCore.QSize(40, 0))
        self.label_15.setObjectName("label_15")
        self.gridLayout_5.addWidget(self.label_15, 2, 2, 1, 1)
        self.tabRegion.addTab(self.tabLine, "")
        self.tabRectangle = QtGui.QWidget()
        self.tabRectangle.setObjectName("tabRectangle")
        self.gridLayout_6 = QtGui.QGridLayout(self.tabRectangle)
        self.gridLayout_6.setObjectName("gridLayout_6")
        spacerItem6 = QtGui.QSpacerItem(26, 20, QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Minimum)
        self.gridLayout_6.addItem(spacerItem6, 0, 1, 1, 1)
        self.rs_label0_8 = QtGui.QLabel(self.tabRectangle)
        self.rs_label0_8.setMinimumSize(QtCore.QSize(40, 0))
        self.rs_label0_8.setObjectName("rs_label0_8")
        self.gridLayout_6.addWidget(self.rs_label0_8, 0, 2, 1, 1)
        self.rect_tx0 = QtGui.QLineEdit(self.tabRectangle)
        self.rect_tx0.setObjectName("rect_tx0")
        self.gridLayout_6.addWidget(self.rect_tx0, 0, 3, 1, 1)
        self.point_label0_15 = QtGui.QLabel(self.tabRectangle)
        self.point_label0_15.setObjectName("point_label0_15")
        self.gridLayout_6.addWidget(self.point_label0_15, 0, 4, 1, 1)
        self.rect_tx1 = QtGui.QLineEdit(self.tabRectangle)
        self.rect_tx1.setText("")
        self.rect_tx1.setObjectName("rect_tx1")
        self.gridLayout_6.addWidget(self.rect_tx1, 0, 5, 1, 1)
        spacerItem7 = QtGui.QSpacerItem(48, 20, QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Minimum)
        self.gridLayout_6.addItem(spacerItem7, 1, 0, 1, 1)
        self.rs_label0_7 = QtGui.QLabel(self.tabRectangle)
        self.rs_label0_7.setObjectName("rs_label0_7")
        self.gridLayout_6.addWidget(self.rs_label0_7, 1, 2, 1, 1)
        self.rect_tx2 = QtGui.QLineEdit(self.tabRectangle)
        self.rect_tx2.setObjectName("rect_tx2")
        self.gridLayout_6.addWidget(self.rect_tx2, 1, 3, 1, 1)
        self.point_label0_17 = QtGui.QLabel(self.tabRectangle)
        self.point_label0_17.setObjectName("point_label0_17")
        self.gridLayout_6.addWidget(self.point_label0_17, 1, 4, 1, 1)
        self.rect_tx3 = QtGui.QLineEdit(self.tabRectangle)
        self.rect_tx3.setObjectName("rect_tx3")
        self.gridLayout_6.addWidget(self.rect_tx3, 1, 5, 1, 1)
        spacerItem8 = QtGui.QSpacerItem(26, 20, QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Minimum)
        self.gridLayout_6.addItem(spacerItem8, 2, 1, 1, 1)
        self.tabRegion.addTab(self.tabRectangle, "")
        self.tabCircle = QtGui.QWidget()
        self.tabCircle.setObjectName("tabCircle")
        self.gridLayout_4 = QtGui.QGridLayout(self.tabCircle)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.label_11 = QtGui.QLabel(self.tabCircle)
        self.label_11.setObjectName("label_11")
        self.gridLayout_4.addWidget(self.label_11, 0, 0, 1, 1)
        spacerItem9 = QtGui.QSpacerItem(47, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.gridLayout_4.addItem(spacerItem9, 0, 1, 1, 1)
        self.rs_label0_4 = QtGui.QLabel(self.tabCircle)
        self.rs_label0_4.setMinimumSize(QtCore.QSize(38, 0))
        self.rs_label0_4.setObjectName("rs_label0_4")
        self.gridLayout_4.addWidget(self.rs_label0_4, 0, 2, 1, 1)
        self.circle_tx0 = QtGui.QLineEdit(self.tabCircle)
        self.circle_tx0.setObjectName("circle_tx0")
        self.gridLayout_4.addWidget(self.circle_tx0, 0, 3, 1, 1)
        self.point_label0_12 = QtGui.QLabel(self.tabCircle)
        self.point_label0_12.setObjectName("point_label0_12")
        self.gridLayout_4.addWidget(self.point_label0_12, 0, 4, 1, 1)
        self.circle_tx1 = QtGui.QLineEdit(self.tabCircle)
        self.circle_tx1.setText("")
        self.circle_tx1.setObjectName("circle_tx1")
        self.gridLayout_4.addWidget(self.circle_tx1, 0, 5, 1, 1)
        self.label_10 = QtGui.QLabel(self.tabCircle)
        self.label_10.setObjectName("label_10")
        self.gridLayout_4.addWidget(self.label_10, 1, 0, 1, 1)
        self.circle_tx2 = QtGui.QLineEdit(self.tabCircle)
        self.circle_tx2.setObjectName("circle_tx2")
        self.gridLayout_4.addWidget(self.circle_tx2, 1, 3, 1, 1)
        spacerItem10 = QtGui.QSpacerItem(47, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.gridLayout_4.addItem(spacerItem10, 2, 1, 1, 1)
        spacerItem11 = QtGui.QSpacerItem(48, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.gridLayout_4.addItem(spacerItem11, 2, 0, 1, 1)
        self.tabRegion.addTab(self.tabCircle, "")
        self.tabRing = QtGui.QWidget()
        self.tabRing.setObjectName("tabRing")
        self.gridLayout_3 = QtGui.QGridLayout(self.tabRing)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.label_9 = QtGui.QLabel(self.tabRing)
        self.label_9.setObjectName("label_9")
        self.gridLayout_3.addWidget(self.label_9, 0, 0, 1, 1)
        self.ring_tx2 = QtGui.QLineEdit(self.tabRing)
        self.ring_tx2.setObjectName("ring_tx2")
        self.gridLayout_3.addWidget(self.ring_tx2, 1, 3, 1, 1)
        self.point_label0_13 = QtGui.QLabel(self.tabRing)
        self.point_label0_13.setTextFormat(QtCore.Qt.AutoText)
        self.point_label0_13.setObjectName("point_label0_13")
        self.gridLayout_3.addWidget(self.point_label0_13, 1, 4, 1, 1)
        self.ring_tx3 = QtGui.QLineEdit(self.tabRing)
        self.ring_tx3.setObjectName("ring_tx3")
        self.gridLayout_3.addWidget(self.ring_tx3, 1, 5, 1, 1)
        self.rs_label0_3 = QtGui.QLabel(self.tabRing)
        self.rs_label0_3.setMinimumSize(QtCore.QSize(38, 0))
        self.rs_label0_3.setObjectName("rs_label0_3")
        self.gridLayout_3.addWidget(self.rs_label0_3, 0, 2, 1, 1)
        self.ring_tx1 = QtGui.QLineEdit(self.tabRing)
        self.ring_tx1.setText("")
        self.ring_tx1.setObjectName("ring_tx1")
        self.gridLayout_3.addWidget(self.ring_tx1, 0, 5, 1, 1)
        self.ring_tx0 = QtGui.QLineEdit(self.tabRing)
        self.ring_tx0.setObjectName("ring_tx0")
        self.gridLayout_3.addWidget(self.ring_tx0, 0, 3, 1, 1)
        self.point_label0_11 = QtGui.QLabel(self.tabRing)
        self.point_label0_11.setMinimumSize(QtCore.QSize(38, 0))
        self.point_label0_11.setObjectName("point_label0_11")
        self.gridLayout_3.addWidget(self.point_label0_11, 0, 4, 1, 1)
        spacerItem12 = QtGui.QSpacerItem(32, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.gridLayout_3.addItem(spacerItem12, 0, 1, 1, 1)
        self.label_8 = QtGui.QLabel(self.tabRing)
        self.label_8.setObjectName("label_8")
        self.gridLayout_3.addWidget(self.label_8, 1, 0, 1, 1)
        spacerItem13 = QtGui.QSpacerItem(32, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.gridLayout_3.addItem(spacerItem13, 2, 1, 1, 1)
        spacerItem14 = QtGui.QSpacerItem(48, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.gridLayout_3.addItem(spacerItem14, 2, 0, 1, 1)
        self.tabRegion.addTab(self.tabRing, "")
        self.tabSector = QtGui.QWidget()
        self.tabSector.setObjectName("tabSector")
        self.gridLayout_2 = QtGui.QGridLayout(self.tabSector)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.label_6 = QtGui.QLabel(self.tabSector)
        self.label_6.setMinimumSize(QtCore.QSize(48, 0))
        self.label_6.setObjectName("label_6")
        self.gridLayout_2.addWidget(self.label_6, 0, 0, 1, 1)
        spacerItem15 = QtGui.QSpacerItem(32, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.gridLayout_2.addItem(spacerItem15, 0, 1, 1, 1)
        self.rs_label0_2 = QtGui.QLabel(self.tabSector)
        self.rs_label0_2.setMinimumSize(QtCore.QSize(38, 0))
        self.rs_label0_2.setObjectName("rs_label0_2")
        self.gridLayout_2.addWidget(self.rs_label0_2, 0, 2, 1, 1)
        self.sector_tx0 = QtGui.QLineEdit(self.tabSector)
        self.sector_tx0.setObjectName("sector_tx0")
        self.gridLayout_2.addWidget(self.sector_tx0, 0, 3, 1, 1)
        self.point_label0_7 = QtGui.QLabel(self.tabSector)
        self.point_label0_7.setMinimumSize(QtCore.QSize(38, 0))
        self.point_label0_7.setObjectName("point_label0_7")
        self.gridLayout_2.addWidget(self.point_label0_7, 0, 4, 1, 1)
        self.sector_tx1 = QtGui.QLineEdit(self.tabSector)
        self.sector_tx1.setText("")
        self.sector_tx1.setObjectName("sector_tx1")
        self.gridLayout_2.addWidget(self.sector_tx1, 0, 5, 1, 1)
        self.label_5 = QtGui.QLabel(self.tabSector)
        self.label_5.setObjectName("label_5")
        self.gridLayout_2.addWidget(self.label_5, 1, 0, 1, 1)
        self.sector_tx2 = QtGui.QLineEdit(self.tabSector)
        self.sector_tx2.setObjectName("sector_tx2")
        self.gridLayout_2.addWidget(self.sector_tx2, 1, 3, 1, 1)
        self.label_7 = QtGui.QLabel(self.tabSector)
        self.label_7.setObjectName("label_7")
        self.gridLayout_2.addWidget(self.label_7, 2, 0, 1, 1)
        self.sector_tx4 = QtGui.QLineEdit(self.tabSector)
        self.sector_tx4.setObjectName("sector_tx4")
        self.gridLayout_2.addWidget(self.sector_tx4, 2, 3, 1, 1)
        self.point_label0_10 = QtGui.QLabel(self.tabSector)
        self.point_label0_10.setTextFormat(QtCore.Qt.AutoText)
        self.point_label0_10.setObjectName("point_label0_10")
        self.gridLayout_2.addWidget(self.point_label0_10, 2, 4, 1, 1)
        self.sector_tx5 = QtGui.QLineEdit(self.tabSector)
        self.sector_tx5.setObjectName("sector_tx5")
        self.gridLayout_2.addWidget(self.sector_tx5, 2, 5, 1, 1)
        self.tabRegion.addTab(self.tabSector, "")
        self.tabRingSector = QtGui.QWidget()
        self.tabRingSector.setObjectName("tabRingSector")
        self.gridLayout = QtGui.QGridLayout(self.tabRingSector)
        self.gridLayout.setSizeConstraint(QtGui.QLayout.SetNoConstraint)
        self.gridLayout.setObjectName("gridLayout")
        self.point_label0_8 = QtGui.QLabel(self.tabRingSector)
        self.point_label0_8.setTextFormat(QtCore.Qt.AutoText)
        self.point_label0_8.setObjectName("point_label0_8")
        self.gridLayout.addWidget(self.point_label0_8, 2, 4, 1, 1)
        self.label_3 = QtGui.QLabel(self.tabRingSector)
        self.label_3.setObjectName("label_3")
        self.gridLayout.addWidget(self.label_3, 1, 0, 1, 1)
        self.rs_tx5 = QtGui.QLineEdit(self.tabRingSector)
        self.rs_tx5.setObjectName("rs_tx5")
        self.gridLayout.addWidget(self.rs_tx5, 2, 5, 1, 1)
        self.rs_tx1 = QtGui.QLineEdit(self.tabRingSector)
        self.rs_tx1.setText("")
        self.rs_tx1.setObjectName("rs_tx1")
        self.gridLayout.addWidget(self.rs_tx1, 0, 5, 1, 1)
        self.rs_tx3 = QtGui.QLineEdit(self.tabRingSector)
        self.rs_tx3.setObjectName("rs_tx3")
        self.gridLayout.addWidget(self.rs_tx3, 1, 5, 1, 1)
        self.rs_label0 = QtGui.QLabel(self.tabRingSector)
        self.rs_label0.setMinimumSize(QtCore.QSize(38, 0))
        self.rs_label0.setObjectName("rs_label0")
        self.gridLayout.addWidget(self.rs_label0, 0, 2, 1, 1)
        self.point_label0_9 = QtGui.QLabel(self.tabRingSector)
        self.point_label0_9.setTextFormat(QtCore.Qt.AutoText)
        self.point_label0_9.setObjectName("point_label0_9")
        self.gridLayout.addWidget(self.point_label0_9, 1, 4, 1, 1)
        self.label_4 = QtGui.QLabel(self.tabRingSector)
        self.label_4.setObjectName("label_4")
        self.gridLayout.addWidget(self.label_4, 2, 0, 1, 1)
        self.rs_tx0 = QtGui.QLineEdit(self.tabRingSector)
        self.rs_tx0.setObjectName("rs_tx0")
        self.gridLayout.addWidget(self.rs_tx0, 0, 3, 1, 1)
        self.point_label0_6 = QtGui.QLabel(self.tabRingSector)
        self.point_label0_6.setMinimumSize(QtCore.QSize(38, 0))
        self.point_label0_6.setObjectName("point_label0_6")
        self.gridLayout.addWidget(self.point_label0_6, 0, 4, 1, 1)
        self.rs_tx4 = QtGui.QLineEdit(self.tabRingSector)
        self.rs_tx4.setObjectName("rs_tx4")
        self.gridLayout.addWidget(self.rs_tx4, 2, 3, 1, 1)
        self.rs_tx2 = QtGui.QLineEdit(self.tabRingSector)
        self.rs_tx2.setObjectName("rs_tx2")
        self.gridLayout.addWidget(self.rs_tx2, 1, 3, 1, 1)
        spacerItem16 = QtGui.QSpacerItem(27, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem16, 0, 1, 1, 1)
        self.label_2 = QtGui.QLabel(self.tabRingSector)
        self.label_2.setMinimumSize(QtCore.QSize(48, 0))
        self.label_2.setObjectName("label_2")
        self.gridLayout.addWidget(self.label_2, 0, 0, 1, 1)
        spacerItem17 = QtGui.QSpacerItem(20, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem17, 2, 1, 1, 1)
        self.tabRegion.addTab(self.tabRingSector, "")
        self.frame = QtGui.QFrame(DlgRegion)
        self.frame.setGeometry(QtCore.QRect(280, 220, 241, 341))
        self.frame.setFrameShape(QtGui.QFrame.StyledPanel)
        self.frame.setFrameShadow(QtGui.QFrame.Raised)
        self.frame.setObjectName("frame")
        self.layoutWidget = QtGui.QWidget(self.frame)
        self.layoutWidget.setGeometry(QtCore.QRect(10, 10, 221, 229))
        self.layoutWidget.setObjectName("layoutWidget")
        self.vLayout_group = QtGui.QVBoxLayout(self.layoutWidget)
        self.vLayout_group.setContentsMargins(0, 0, 0, 0)
        self.vLayout_group.setObjectName("vLayout_group")
        self.hLayout_group = QtGui.QHBoxLayout()
        self.hLayout_group.setObjectName("hLayout_group")
        self.btnAddGrp = QtGui.QPushButton(self.layoutWidget)
        self.btnAddGrp.setEnabled(True)
        self.btnAddGrp.setAutoDefault(False)
        self.btnAddGrp.setObjectName("btnAddGrp")
        self.hLayout_group.addWidget(self.btnAddGrp)
        self.btnDeleteGrp = QtGui.QPushButton(self.layoutWidget)
        self.btnDeleteGrp.setEnabled(True)
        self.btnDeleteGrp.setAutoDefault(False)
        self.btnDeleteGrp.setObjectName("btnDeleteGrp")
        self.hLayout_group.addWidget(self.btnDeleteGrp)
        self.vLayout_group.addLayout(self.hLayout_group)
        self.label = QtGui.QLabel(DlgRegion)
        self.label.setGeometry(QtCore.QRect(290, 210, 81, 17))
        self.label.setAutoFillBackground(True)
        self.label.setObjectName("label")
        self.layoutWidget1 = QtGui.QWidget(DlgRegion)
        self.layoutWidget1.setGeometry(QtCore.QRect(90, 170, 100, 38))
        self.layoutWidget1.setObjectName("layoutWidget1")
        self.horizontalLayout_2 = QtGui.QHBoxLayout(self.layoutWidget1)
        self.horizontalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.btnAdd = QtGui.QPushButton(self.layoutWidget1)
        self.btnAdd.setText("")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/Go-down.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnAdd.setIcon(icon1)
        self.btnAdd.setIconSize(QtCore.QSize(24, 24))
        self.btnAdd.setAutoDefault(False)
        self.btnAdd.setObjectName("btnAdd")
        self.horizontalLayout_2.addWidget(self.btnAdd)
        self.btnDelete = QtGui.QPushButton(self.layoutWidget1)
        self.btnDelete.setText("")
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/Edit-delete.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.btnDelete.setIcon(icon2)
        self.btnDelete.setIconSize(QtCore.QSize(24, 24))
        self.btnDelete.setAutoDefault(False)
        self.btnDelete.setObjectName("btnDelete")
        self.horizontalLayout_2.addWidget(self.btnDelete)
        self.btnClose = QtGui.QPushButton(DlgRegion)
        self.btnClose.setGeometry(QtCore.QRect(290, 570, 227, 25))
        self.btnClose.setObjectName("btnClose")

        self.retranslateUi(DlgRegion)
        self.tabRegion.setCurrentIndex(2)
        QtCore.QMetaObject.connectSlotsByName(DlgRegion)
        DlgRegion.setTabOrder(self.tabRegion, self.point_tx0)
        DlgRegion.setTabOrder(self.point_tx0, self.point_tx1)
        DlgRegion.setTabOrder(self.point_tx1, self.line_tx0)
        DlgRegion.setTabOrder(self.line_tx0, self.line_tx1)
        DlgRegion.setTabOrder(self.line_tx1, self.line_tx2)
        DlgRegion.setTabOrder(self.line_tx2, self.line_tx3)
        DlgRegion.setTabOrder(self.line_tx3, self.line_tx4)
        DlgRegion.setTabOrder(self.line_tx4, self.rect_tx0)
        DlgRegion.setTabOrder(self.rect_tx0, self.rect_tx1)
        DlgRegion.setTabOrder(self.rect_tx1, self.rect_tx2)
        DlgRegion.setTabOrder(self.rect_tx2, self.rect_tx3)
        DlgRegion.setTabOrder(self.rect_tx3, self.circle_tx0)
        DlgRegion.setTabOrder(self.circle_tx0, self.circle_tx1)
        DlgRegion.setTabOrder(self.circle_tx1, self.circle_tx2)
        DlgRegion.setTabOrder(self.circle_tx2, self.ring_tx0)
        DlgRegion.setTabOrder(self.ring_tx0, self.ring_tx1)
        DlgRegion.setTabOrder(self.ring_tx1, self.ring_tx2)
        DlgRegion.setTabOrder(self.ring_tx2, self.ring_tx3)
        DlgRegion.setTabOrder(self.ring_tx3, self.sector_tx0)
        DlgRegion.setTabOrder(self.sector_tx0, self.sector_tx1)
        DlgRegion.setTabOrder(self.sector_tx1, self.sector_tx2)
        DlgRegion.setTabOrder(self.sector_tx2, self.sector_tx4)
        DlgRegion.setTabOrder(self.sector_tx4, self.sector_tx5)
        DlgRegion.setTabOrder(self.sector_tx5, self.rs_tx0)
        DlgRegion.setTabOrder(self.rs_tx0, self.rs_tx1)
        DlgRegion.setTabOrder(self.rs_tx1, self.rs_tx2)
        DlgRegion.setTabOrder(self.rs_tx2, self.rs_tx3)
        DlgRegion.setTabOrder(self.rs_tx3, self.rs_tx4)
        DlgRegion.setTabOrder(self.rs_tx4, self.rs_tx5)
        DlgRegion.setTabOrder(self.rs_tx5, self.btnAdd)
        DlgRegion.setTabOrder(self.btnAdd, self.btnDelete)
        DlgRegion.setTabOrder(self.btnDelete, self.btnAddGrp)
        DlgRegion.setTabOrder(self.btnAddGrp, self.btnDeleteGrp)
        DlgRegion.setTabOrder(self.btnDeleteGrp, self.btnClose)

    def retranslateUi(self, DlgRegion):
        DlgRegion.setWindowTitle(QtGui.QApplication.translate("DlgRegion", "Set Regions", None, QtGui.QApplication.UnicodeUTF8))
        self.tabPoint.setProperty("tabName", QtGui.QApplication.translate("DlgRegion", "Point", None, QtGui.QApplication.UnicodeUTF8))
        self.rs_label0_10.setText(QtGui.QApplication.translate("DlgRegion", "X0:", None, QtGui.QApplication.UnicodeUTF8))
        self.point_label0_18.setText(QtGui.QApplication.translate("DlgRegion", "Y0:", None, QtGui.QApplication.UnicodeUTF8))
        self.tabRegion.setTabText(self.tabRegion.indexOf(self.tabPoint), QtGui.QApplication.translate("DlgRegion", "Point", None, QtGui.QApplication.UnicodeUTF8))
        self.tabLine.setProperty("tabName", QtGui.QApplication.translate("DlgRegion", "Line", None, QtGui.QApplication.UnicodeUTF8))
        self.rs_label0_5.setText(QtGui.QApplication.translate("DlgRegion", "X0:", None, QtGui.QApplication.UnicodeUTF8))
        self.point_label0_14.setText(QtGui.QApplication.translate("DlgRegion", "Y0:", None, QtGui.QApplication.UnicodeUTF8))
        self.rs_label0_6.setText(QtGui.QApplication.translate("DlgRegion", "X1:", None, QtGui.QApplication.UnicodeUTF8))
        self.point_label0_16.setText(QtGui.QApplication.translate("DlgRegion", "Y1:", None, QtGui.QApplication.UnicodeUTF8))
        self.label_15.setText(QtGui.QApplication.translate("DlgRegion", "Width", None, QtGui.QApplication.UnicodeUTF8))
        self.tabRegion.setTabText(self.tabRegion.indexOf(self.tabLine), QtGui.QApplication.translate("DlgRegion", "Line", None, QtGui.QApplication.UnicodeUTF8))
        self.tabRectangle.setProperty("tabName", QtGui.QApplication.translate("DlgRegion", "Rectangle", None, QtGui.QApplication.UnicodeUTF8))
        self.rs_label0_8.setText(QtGui.QApplication.translate("DlgRegion", "X0:", None, QtGui.QApplication.UnicodeUTF8))
        self.point_label0_15.setText(QtGui.QApplication.translate("DlgRegion", "Y0:", None, QtGui.QApplication.UnicodeUTF8))
        self.rs_label0_7.setText(QtGui.QApplication.translate("DlgRegion", "X1:", None, QtGui.QApplication.UnicodeUTF8))
        self.point_label0_17.setText(QtGui.QApplication.translate("DlgRegion", "Y1:", None, QtGui.QApplication.UnicodeUTF8))
        self.tabRegion.setTabText(self.tabRegion.indexOf(self.tabRectangle), QtGui.QApplication.translate("DlgRegion", "Rectangle", None, QtGui.QApplication.UnicodeUTF8))
        self.tabCircle.setProperty("tabName", QtGui.QApplication.translate("DlgRegion", "Circle", None, QtGui.QApplication.UnicodeUTF8))
        self.label_11.setText(QtGui.QApplication.translate("DlgRegion", "Center", None, QtGui.QApplication.UnicodeUTF8))
        self.rs_label0_4.setText(QtGui.QApplication.translate("DlgRegion", "X0:", None, QtGui.QApplication.UnicodeUTF8))
        self.point_label0_12.setText(QtGui.QApplication.translate("DlgRegion", "Y0:", None, QtGui.QApplication.UnicodeUTF8))
        self.label_10.setText(QtGui.QApplication.translate("DlgRegion", "Radius", None, QtGui.QApplication.UnicodeUTF8))
        self.tabRegion.setTabText(self.tabRegion.indexOf(self.tabCircle), QtGui.QApplication.translate("DlgRegion", "Circle", None, QtGui.QApplication.UnicodeUTF8))
        self.tabRing.setProperty("tabName", QtGui.QApplication.translate("DlgRegion", "Ring", None, QtGui.QApplication.UnicodeUTF8))
        self.label_9.setText(QtGui.QApplication.translate("DlgRegion", "Center", None, QtGui.QApplication.UnicodeUTF8))
        self.point_label0_13.setText(QtGui.QApplication.translate("DlgRegion", "±", None, QtGui.QApplication.UnicodeUTF8))
        self.rs_label0_3.setText(QtGui.QApplication.translate("DlgRegion", "X0:", None, QtGui.QApplication.UnicodeUTF8))
        self.point_label0_11.setText(QtGui.QApplication.translate("DlgRegion", "Y0:", None, QtGui.QApplication.UnicodeUTF8))
        self.label_8.setText(QtGui.QApplication.translate("DlgRegion", "Radius", None, QtGui.QApplication.UnicodeUTF8))
        self.tabRegion.setTabText(self.tabRegion.indexOf(self.tabRing), QtGui.QApplication.translate("DlgRegion", "Ring", None, QtGui.QApplication.UnicodeUTF8))
        self.tabSector.setProperty("tabName", QtGui.QApplication.translate("DlgRegion", "Sector", None, QtGui.QApplication.UnicodeUTF8))
        self.label_6.setText(QtGui.QApplication.translate("DlgRegion", "Center", None, QtGui.QApplication.UnicodeUTF8))
        self.rs_label0_2.setText(QtGui.QApplication.translate("DlgRegion", "X0:", None, QtGui.QApplication.UnicodeUTF8))
        self.point_label0_7.setText(QtGui.QApplication.translate("DlgRegion", "Y0:", None, QtGui.QApplication.UnicodeUTF8))
        self.label_5.setText(QtGui.QApplication.translate("DlgRegion", "Radius", None, QtGui.QApplication.UnicodeUTF8))
        self.label_7.setText(QtGui.QApplication.translate("DlgRegion", "Angle", None, QtGui.QApplication.UnicodeUTF8))
        self.point_label0_10.setText(QtGui.QApplication.translate("DlgRegion", "±", None, QtGui.QApplication.UnicodeUTF8))
        self.tabRegion.setTabText(self.tabRegion.indexOf(self.tabSector), QtGui.QApplication.translate("DlgRegion", "Sector", None, QtGui.QApplication.UnicodeUTF8))
        self.tabRingSector.setProperty("tabName", QtGui.QApplication.translate("DlgRegion", "Ring Sector", None, QtGui.QApplication.UnicodeUTF8))
        self.point_label0_8.setText(QtGui.QApplication.translate("DlgRegion", "±", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("DlgRegion", "Radius", None, QtGui.QApplication.UnicodeUTF8))
        self.rs_label0.setText(QtGui.QApplication.translate("DlgRegion", "X0:", None, QtGui.QApplication.UnicodeUTF8))
        self.point_label0_9.setText(QtGui.QApplication.translate("DlgRegion", "±", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("DlgRegion", "Angle", None, QtGui.QApplication.UnicodeUTF8))
        self.point_label0_6.setText(QtGui.QApplication.translate("DlgRegion", "Y0:", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("DlgRegion", "Center", None, QtGui.QApplication.UnicodeUTF8))
        self.tabRegion.setTabText(self.tabRegion.indexOf(self.tabRingSector), QtGui.QApplication.translate("DlgRegion", "Ring Sector", None, QtGui.QApplication.UnicodeUTF8))
        self.btnAddGrp.setText(QtGui.QApplication.translate("DlgRegion", "Add", None, QtGui.QApplication.UnicodeUTF8))
        self.btnDeleteGrp.setText(QtGui.QApplication.translate("DlgRegion", "Delete", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("DlgRegion", "Edit Groups", None, QtGui.QApplication.UnicodeUTF8))
        self.btnClose.setText(QtGui.QApplication.translate("DlgRegion", "Close", None, QtGui.QApplication.UnicodeUTF8))

try:
    import dg_region_rc
except:
    import uGao.dg_region_rc

# Form implementation generated from reading ui file 'dg_slice.ui'
#
# Created: Tue Mar 16 11:01:39 2021
#      by: pyside-uic 0.2.15 running on PySide 1.2.2
#
# WARNING! All changes made in this file will be lost!


class Ui_DlgSlice(object):
    def setupUi(self, DlgSlice):
        DlgSlice.setObjectName("DlgSlice")
        DlgSlice.resize(293, 287)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/ugao_icon.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        DlgSlice.setWindowIcon(icon)
        self.buttonBox = QtGui.QDialogButtonBox(DlgSlice)
        self.buttonBox.setGeometry(QtCore.QRect(10, 250, 271, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Apply|QtGui.QDialogButtonBox.Close|QtGui.QDialogButtonBox.Reset)
        self.buttonBox.setObjectName("buttonBox")
        self.groupBox = QtGui.QGroupBox(DlgSlice)
        self.groupBox.setGeometry(QtCore.QRect(10, 0, 271, 121))
        self.groupBox.setObjectName("groupBox")
        self.gridLayoutWidget = QtGui.QWidget(self.groupBox)
        self.gridLayoutWidget.setGeometry(QtCore.QRect(10, 20, 251, 95))
        self.gridLayoutWidget.setObjectName("gridLayoutWidget")
        self.gridLayout = QtGui.QGridLayout(self.gridLayoutWidget)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setObjectName("gridLayout")
        self.radio_yvalue = QtGui.QRadioButton(self.gridLayoutWidget)
        self.radio_yvalue.setChecked(True)
        self.radio_yvalue.setObjectName("radio_yvalue")
        self.gridLayout.addWidget(self.radio_yvalue, 0, 0, 1, 1)
        self.txt_y_center = QtGui.QLineEdit(self.gridLayoutWidget)
        self.txt_y_center.setObjectName("txt_y_center")
        self.gridLayout.addWidget(self.txt_y_center, 0, 1, 1, 1)
        self.txt_y_start = QtGui.QLineEdit(self.gridLayoutWidget)
        self.txt_y_start.setEnabled(False)
        self.txt_y_start.setText("")
        self.txt_y_start.setObjectName("txt_y_start")
        self.gridLayout.addWidget(self.txt_y_start, 1, 1, 1, 1)
        self.label = QtGui.QLabel(self.gridLayoutWidget)
        self.label.setAlignment(QtCore.Qt.AlignCenter)
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 0, 2, 1, 1)
        self.radio_yrange = QtGui.QRadioButton(self.gridLayoutWidget)
        self.radio_yrange.setObjectName("radio_yrange")
        self.gridLayout.addWidget(self.radio_yrange, 1, 0, 1, 1)
        self.label_2 = QtGui.QLabel(self.gridLayoutWidget)
        self.label_2.setEnabled(False)
        self.label_2.setAlignment(QtCore.Qt.AlignCenter)
        self.label_2.setObjectName("label_2")
        self.gridLayout.addWidget(self.label_2, 1, 2, 1, 1)
        self.txt_y_width = QtGui.QLineEdit(self.gridLayoutWidget)
        self.txt_y_width.setObjectName("txt_y_width")
        self.gridLayout.addWidget(self.txt_y_width, 0, 3, 1, 1)
        self.txt_y_end = QtGui.QLineEdit(self.gridLayoutWidget)
        self.txt_y_end.setEnabled(False)
        self.txt_y_end.setObjectName("txt_y_end")
        self.gridLayout.addWidget(self.txt_y_end, 1, 3, 1, 1)
        self.cb_sliceXbin = QtGui.QCheckBox(self.gridLayoutWidget)
        self.cb_sliceXbin.setObjectName("cb_sliceXbin")
        self.gridLayout.addWidget(self.cb_sliceXbin, 2, 0, 1, 1)
        self.txt_xbin = QtGui.QLineEdit(self.gridLayoutWidget)
        self.txt_xbin.setObjectName("txt_xbin")
        self.gridLayout.addWidget(self.txt_xbin, 2, 1, 1, 1)
        self.groupBox_2 = QtGui.QGroupBox(DlgSlice)
        self.groupBox_2.setGeometry(QtCore.QRect(10, 120, 271, 121))
        self.groupBox_2.setObjectName("groupBox_2")
        self.gridLayoutWidget_2 = QtGui.QWidget(self.groupBox_2)
        self.gridLayoutWidget_2.setGeometry(QtCore.QRect(10, 20, 251, 95))
        self.gridLayoutWidget_2.setObjectName("gridLayoutWidget_2")
        self.gridLayout_2 = QtGui.QGridLayout(self.gridLayoutWidget_2)
        self.gridLayout_2.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.label_3 = QtGui.QLabel(self.gridLayoutWidget_2)
        self.label_3.setAlignment(QtCore.Qt.AlignCenter)
        self.label_3.setObjectName("label_3")
        self.gridLayout_2.addWidget(self.label_3, 0, 2, 1, 1)
        self.label_4 = QtGui.QLabel(self.gridLayoutWidget_2)
        self.label_4.setEnabled(False)
        self.label_4.setAlignment(QtCore.Qt.AlignCenter)
        self.label_4.setObjectName("label_4")
        self.gridLayout_2.addWidget(self.label_4, 1, 2, 1, 1)
        self.radio_xvalue = QtGui.QRadioButton(self.gridLayoutWidget_2)
        self.radio_xvalue.setChecked(True)
        self.radio_xvalue.setObjectName("radio_xvalue")
        self.gridLayout_2.addWidget(self.radio_xvalue, 0, 0, 1, 1)
        self.txt_x_center = QtGui.QLineEdit(self.gridLayoutWidget_2)
        self.txt_x_center.setObjectName("txt_x_center")
        self.gridLayout_2.addWidget(self.txt_x_center, 0, 1, 1, 1)
        self.txt_x_start = QtGui.QLineEdit(self.gridLayoutWidget_2)
        self.txt_x_start.setEnabled(False)
        self.txt_x_start.setText("")
        self.txt_x_start.setObjectName("txt_x_start")
        self.gridLayout_2.addWidget(self.txt_x_start, 1, 1, 1, 1)
        self.radio_xrange = QtGui.QRadioButton(self.gridLayoutWidget_2)
        self.radio_xrange.setObjectName("radio_xrange")
        self.gridLayout_2.addWidget(self.radio_xrange, 1, 0, 1, 1)
        self.txt_x_width = QtGui.QLineEdit(self.gridLayoutWidget_2)
        self.txt_x_width.setObjectName("txt_x_width")
        self.gridLayout_2.addWidget(self.txt_x_width, 0, 3, 1, 1)
        self.txt_x_end = QtGui.QLineEdit(self.gridLayoutWidget_2)
        self.txt_x_end.setEnabled(False)
        self.txt_x_end.setObjectName("txt_x_end")
        self.gridLayout_2.addWidget(self.txt_x_end, 1, 3, 1, 1)
        self.cb_sliceYbin = QtGui.QCheckBox(self.gridLayoutWidget_2)
        self.cb_sliceYbin.setObjectName("cb_sliceYbin")
        self.gridLayout_2.addWidget(self.cb_sliceYbin, 2, 0, 1, 1)
        self.txt_ybin = QtGui.QLineEdit(self.gridLayoutWidget_2)
        self.txt_ybin.setObjectName("txt_ybin")
        self.gridLayout_2.addWidget(self.txt_ybin, 2, 1, 1, 1)

        self.retranslateUi(DlgSlice)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL("accepted()"), DlgSlice.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL("rejected()"), DlgSlice.reject)
        QtCore.QObject.connect(self.radio_yrange, QtCore.SIGNAL("toggled(bool)"), self.txt_y_start.setEnabled)
        QtCore.QObject.connect(self.radio_yrange, QtCore.SIGNAL("toggled(bool)"), self.txt_y_end.setEnabled)
        QtCore.QObject.connect(self.radio_yvalue, QtCore.SIGNAL("toggled(bool)"), self.txt_y_center.setEnabled)
        QtCore.QObject.connect(self.radio_yvalue, QtCore.SIGNAL("toggled(bool)"), self.txt_y_width.setEnabled)
        QtCore.QObject.connect(self.radio_xvalue, QtCore.SIGNAL("toggled(bool)"), self.txt_x_center.setEnabled)
        QtCore.QObject.connect(self.radio_xvalue, QtCore.SIGNAL("toggled(bool)"), self.txt_x_width.setEnabled)
        QtCore.QObject.connect(self.radio_xrange, QtCore.SIGNAL("toggled(bool)"), self.txt_x_start.setEnabled)
        QtCore.QObject.connect(self.radio_xrange, QtCore.SIGNAL("toggled(bool)"), self.txt_x_end.setEnabled)
        QtCore.QObject.connect(self.radio_yrange, QtCore.SIGNAL("toggled(bool)"), self.label_2.setEnabled)
        QtCore.QObject.connect(self.radio_yvalue, QtCore.SIGNAL("toggled(bool)"), self.label.setEnabled)
        QtCore.QObject.connect(self.radio_xvalue, QtCore.SIGNAL("toggled(bool)"), self.label_3.setEnabled)
        QtCore.QObject.connect(self.radio_xrange, QtCore.SIGNAL("toggled(bool)"), self.label_4.setEnabled)
        QtCore.QMetaObject.connectSlotsByName(DlgSlice)
        DlgSlice.setTabOrder(self.radio_yvalue, self.txt_y_center)
        DlgSlice.setTabOrder(self.txt_y_center, self.txt_y_width)
        DlgSlice.setTabOrder(self.txt_y_width, self.radio_yrange)
        DlgSlice.setTabOrder(self.radio_yrange, self.txt_y_start)
        DlgSlice.setTabOrder(self.txt_y_start, self.txt_y_end)
        DlgSlice.setTabOrder(self.txt_y_end, self.radio_xvalue)
        DlgSlice.setTabOrder(self.radio_xvalue, self.txt_x_center)
        DlgSlice.setTabOrder(self.txt_x_center, self.txt_x_width)
        DlgSlice.setTabOrder(self.txt_x_width, self.radio_xrange)
        DlgSlice.setTabOrder(self.radio_xrange, self.txt_x_start)
        DlgSlice.setTabOrder(self.txt_x_start, self.txt_x_end)
        DlgSlice.setTabOrder(self.txt_x_end, self.buttonBox)

    def retranslateUi(self, DlgSlice):
        DlgSlice.setWindowTitle(QtGui.QApplication.translate("DlgSlice", "Slice Regions", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox.setTitle(QtGui.QApplication.translate("DlgSlice", "X-Intensity Graph", None, QtGui.QApplication.UnicodeUTF8))
        self.radio_yvalue.setText(QtGui.QApplication.translate("DlgSlice", "Y value", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("DlgSlice", "±", None, QtGui.QApplication.UnicodeUTF8))
        self.radio_yrange.setText(QtGui.QApplication.translate("DlgSlice", "Y range", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("DlgSlice", "-", None, QtGui.QApplication.UnicodeUTF8))
        self.cb_sliceXbin.setText(QtGui.QApplication.translate("DlgSlice", "rebin", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox_2.setTitle(QtGui.QApplication.translate("DlgSlice", "Y-Intensity Graph", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("DlgSlice", "±", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("DlgSlice", "-", None, QtGui.QApplication.UnicodeUTF8))
        self.radio_xvalue.setText(QtGui.QApplication.translate("DlgSlice", "X value", None, QtGui.QApplication.UnicodeUTF8))
        self.radio_xrange.setText(QtGui.QApplication.translate("DlgSlice", "X range", None, QtGui.QApplication.UnicodeUTF8))
        self.cb_sliceYbin.setText(QtGui.QApplication.translate("DlgSlice", "rebin", None, QtGui.QApplication.UnicodeUTF8))


# Form implementation generated from reading ui file 'dg_view_prms.ui'
#
# Created: Tue Mar 16 11:01:39 2021
#      by: pyside-uic 0.2.15 running on PySide 1.2.2
#
# WARNING! All changes made in this file will be lost!


class Ui_DlgViewPrms(object):
    def setupUi(self, DlgViewPrms):
        DlgViewPrms.setObjectName("DlgViewPrms")
        DlgViewPrms.resize(440, 580)
        font = QtGui.QFont()
        font.setFamily("Sans Serif")
        font.setPointSize(9)
        DlgViewPrms.setFont(font)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/ugao_icon.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        DlgViewPrms.setWindowIcon(icon)
        self.tabWidget = QtGui.QTabWidget(DlgViewPrms)
        self.tabWidget.setGeometry(QtCore.QRect(10, 10, 421, 191))
        self.tabWidget.setObjectName("tabWidget")
        self.tab = QtGui.QWidget()
        self.tab.setObjectName("tab")
        self.layoutWidget_2 = QtGui.QWidget(self.tab)
        self.layoutWidget_2.setGeometry(QtCore.QRect(10, 50, 401, 37))
        self.layoutWidget_2.setObjectName("layoutWidget_2")
        self.horizontalLayout_9 = QtGui.QHBoxLayout(self.layoutWidget_2)
        self.horizontalLayout_9.setSizeConstraint(QtGui.QLayout.SetNoConstraint)
        self.horizontalLayout_9.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.check_x_auto_range = QtGui.QCheckBox(self.layoutWidget_2)
        self.check_x_auto_range.setChecked(True)
        self.check_x_auto_range.setObjectName("check_x_auto_range")
        self.horizontalLayout_9.addWidget(self.check_x_auto_range)
        self.horizontalLayout_10 = QtGui.QHBoxLayout()
        self.horizontalLayout_10.setObjectName("horizontalLayout_10")
        self.label_12 = QtGui.QLabel(self.layoutWidget_2)
        self.label_12.setEnabled(False)
        self.label_12.setObjectName("label_12")
        self.horizontalLayout_10.addWidget(self.label_12)
        self.txt_x_min = QtGui.QLineEdit(self.layoutWidget_2)
        self.txt_x_min.setEnabled(False)
        self.txt_x_min.setObjectName("txt_x_min")
        self.horizontalLayout_10.addWidget(self.txt_x_min)
        self.label_13 = QtGui.QLabel(self.layoutWidget_2)
        self.label_13.setEnabled(False)
        self.label_13.setObjectName("label_13")
        self.horizontalLayout_10.addWidget(self.label_13)
        self.txt_x_max = QtGui.QLineEdit(self.layoutWidget_2)
        self.txt_x_max.setEnabled(False)
        self.txt_x_max.setObjectName("txt_x_max")
        self.horizontalLayout_10.addWidget(self.txt_x_max)
        self.horizontalLayout_9.addLayout(self.horizontalLayout_10)
        self.check_x_log = QtGui.QCheckBox(self.tab)
        self.check_x_log.setGeometry(QtCore.QRect(230, 10, 97, 22))
        self.check_x_log.setObjectName("check_x_log")
        self.check_x_inv = QtGui.QCheckBox(self.tab)
        self.check_x_inv.setGeometry(QtCore.QRect(330, 10, 91, 22))
        self.check_x_inv.setObjectName("check_x_inv")
        self.layoutWidget = QtGui.QWidget(self.tab)
        self.layoutWidget.setGeometry(QtCore.QRect(10, 120, 407, 35))
        self.layoutWidget.setObjectName("layoutWidget")
        self.horizontalLayout_7 = QtGui.QHBoxLayout(self.layoutWidget)
        self.horizontalLayout_7.setSizeConstraint(QtGui.QLayout.SetDefaultConstraint)
        self.horizontalLayout_7.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.check_x_auto_tick = QtGui.QCheckBox(self.layoutWidget)
        self.check_x_auto_tick.setChecked(True)
        self.check_x_auto_tick.setObjectName("check_x_auto_tick")
        self.horizontalLayout_7.addWidget(self.check_x_auto_tick)
        spacerItem = QtGui.QSpacerItem(10, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.horizontalLayout_7.addItem(spacerItem)
        self.label_9 = QtGui.QLabel(self.layoutWidget)
        self.label_9.setEnabled(False)
        self.label_9.setObjectName("label_9")
        self.horizontalLayout_7.addWidget(self.label_9)
        self.combo_x_format = QtGui.QComboBox(self.layoutWidget)
        self.combo_x_format.setObjectName("combo_x_format")
        self.horizontalLayout_7.addWidget(self.combo_x_format)
        spacerItem1 = QtGui.QSpacerItem(10, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.horizontalLayout_7.addItem(spacerItem1)
        self.label_10 = QtGui.QLabel(self.layoutWidget)
        self.label_10.setEnabled(False)
        self.label_10.setObjectName("label_10")
        self.horizontalLayout_7.addWidget(self.label_10)
        self.spin_x_prec = QtGui.QSpinBox(self.layoutWidget)
        self.spin_x_prec.setEnabled(False)
        self.spin_x_prec.setMaximum(10)
        self.spin_x_prec.setProperty("value", 3)
        self.spin_x_prec.setObjectName("spin_x_prec")
        self.horizontalLayout_7.addWidget(self.spin_x_prec)
        self.label_8 = QtGui.QLabel(self.tab)
        self.label_8.setGeometry(QtCore.QRect(10, 100, 120, 16))
        self.label_8.setObjectName("label_8")
        self.txt_x_label = QtGui.QLineEdit(self.tab)
        self.txt_x_label.setGeometry(QtCore.QRect(50, 10, 111, 26))
        self.txt_x_label.setObjectName("txt_x_label")
        self.txt_x_unit = QtGui.QLineEdit(self.tab)
        self.txt_x_unit.setGeometry(QtCore.QRect(170, 10, 51, 26))
        self.txt_x_unit.setObjectName("txt_x_unit")
        self.label_14 = QtGui.QLabel(self.tab)
        self.label_14.setGeometry(QtCore.QRect(10, 10, 41, 26))
        self.label_14.setObjectName("label_14")
        self.tabWidget.addTab(self.tab, "")
        self.tab_2 = QtGui.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.layoutWidget1 = QtGui.QWidget(self.tab_2)
        self.layoutWidget1.setGeometry(QtCore.QRect(10, 50, 401, 37))
        self.layoutWidget1.setObjectName("layoutWidget1")
        self.horizontalLayout_3 = QtGui.QHBoxLayout(self.layoutWidget1)
        self.horizontalLayout_3.setSizeConstraint(QtGui.QLayout.SetNoConstraint)
        self.horizontalLayout_3.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.check_y_auto_range = QtGui.QCheckBox(self.layoutWidget1)
        self.check_y_auto_range.setChecked(True)
        self.check_y_auto_range.setObjectName("check_y_auto_range")
        self.horizontalLayout_3.addWidget(self.check_y_auto_range)
        self.horizontalLayout_2 = QtGui.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label_4 = QtGui.QLabel(self.layoutWidget1)
        self.label_4.setEnabled(False)
        self.label_4.setObjectName("label_4")
        self.horizontalLayout_2.addWidget(self.label_4)
        self.txt_y_min = QtGui.QLineEdit(self.layoutWidget1)
        self.txt_y_min.setEnabled(False)
        self.txt_y_min.setObjectName("txt_y_min")
        self.horizontalLayout_2.addWidget(self.txt_y_min)
        self.label_5 = QtGui.QLabel(self.layoutWidget1)
        self.label_5.setEnabled(False)
        self.label_5.setObjectName("label_5")
        self.horizontalLayout_2.addWidget(self.label_5)
        self.txt_y_max = QtGui.QLineEdit(self.layoutWidget1)
        self.txt_y_max.setEnabled(False)
        self.txt_y_max.setObjectName("txt_y_max")
        self.horizontalLayout_2.addWidget(self.txt_y_max)
        self.horizontalLayout_3.addLayout(self.horizontalLayout_2)
        self.check_y_log = QtGui.QCheckBox(self.tab_2)
        self.check_y_log.setGeometry(QtCore.QRect(230, 10, 97, 22))
        self.check_y_log.setObjectName("check_y_log")
        self.check_y_inv = QtGui.QCheckBox(self.tab_2)
        self.check_y_inv.setGeometry(QtCore.QRect(330, 10, 97, 22))
        self.check_y_inv.setObjectName("check_y_inv")
        self.layoutWidget2 = QtGui.QWidget(self.tab_2)
        self.layoutWidget2.setGeometry(QtCore.QRect(10, 120, 407, 35))
        self.layoutWidget2.setObjectName("layoutWidget2")
        self.horizontalLayout_6 = QtGui.QHBoxLayout(self.layoutWidget2)
        self.horizontalLayout_6.setSizeConstraint(QtGui.QLayout.SetDefaultConstraint)
        self.horizontalLayout_6.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.check_y_auto_tick = QtGui.QCheckBox(self.layoutWidget2)
        self.check_y_auto_tick.setChecked(True)
        self.check_y_auto_tick.setObjectName("check_y_auto_tick")
        self.horizontalLayout_6.addWidget(self.check_y_auto_tick)
        spacerItem2 = QtGui.QSpacerItem(10, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem2)
        self.label_6 = QtGui.QLabel(self.layoutWidget2)
        self.label_6.setEnabled(False)
        self.label_6.setObjectName("label_6")
        self.horizontalLayout_6.addWidget(self.label_6)
        self.combo_y_format = QtGui.QComboBox(self.layoutWidget2)
        self.combo_y_format.setObjectName("combo_y_format")
        self.horizontalLayout_6.addWidget(self.combo_y_format)
        spacerItem3 = QtGui.QSpacerItem(10, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem3)
        self.label_7 = QtGui.QLabel(self.layoutWidget2)
        self.label_7.setEnabled(False)
        self.label_7.setObjectName("label_7")
        self.horizontalLayout_6.addWidget(self.label_7)
        self.spin_y_prec = QtGui.QSpinBox(self.layoutWidget2)
        self.spin_y_prec.setEnabled(False)
        self.spin_y_prec.setMaximum(10)
        self.spin_y_prec.setProperty("value", 3)
        self.spin_y_prec.setObjectName("spin_y_prec")
        self.horizontalLayout_6.addWidget(self.spin_y_prec)
        self.label_11 = QtGui.QLabel(self.tab_2)
        self.label_11.setGeometry(QtCore.QRect(10, 100, 120, 16))
        self.label_11.setObjectName("label_11")
        self.txt_y_label = QtGui.QLineEdit(self.tab_2)
        self.txt_y_label.setGeometry(QtCore.QRect(50, 10, 111, 26))
        self.txt_y_label.setObjectName("txt_y_label")
        self.txt_y_unit = QtGui.QLineEdit(self.tab_2)
        self.txt_y_unit.setGeometry(QtCore.QRect(170, 10, 51, 26))
        self.txt_y_unit.setObjectName("txt_y_unit")
        self.label_3 = QtGui.QLabel(self.tab_2)
        self.label_3.setGeometry(QtCore.QRect(10, 10, 41, 26))
        self.label_3.setObjectName("label_3")
        self.tabWidget.addTab(self.tab_2, "")
        self.tabWidget_2 = QtGui.QTabWidget(DlgViewPrms)
        self.tabWidget_2.setGeometry(QtCore.QRect(10, 220, 421, 281))
        self.tabWidget_2.setObjectName("tabWidget_2")
        self.tab_3 = QtGui.QWidget()
        self.tab_3.setObjectName("tab_3")
        self.layoutWidget3 = QtGui.QWidget(self.tab_3)
        self.layoutWidget3.setGeometry(QtCore.QRect(10, 10, 401, 231))
        self.layoutWidget3.setObjectName("layoutWidget3")
        self.verticalLayout = QtGui.QVBoxLayout(self.layoutWidget3)
        self.verticalLayout.setSizeConstraint(QtGui.QLayout.SetNoConstraint)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.formLayout_2 = QtGui.QFormLayout()
        self.formLayout_2.setSizeConstraint(QtGui.QLayout.SetNoConstraint)
        self.formLayout_2.setObjectName("formLayout_2")
        self.label = QtGui.QLabel(self.layoutWidget3)
        self.label.setObjectName("label")
        self.formLayout_2.setWidget(0, QtGui.QFormLayout.LabelRole, self.label)
        self.txt_title = QtGui.QLineEdit(self.layoutWidget3)
        self.txt_title.setObjectName("txt_title")
        self.formLayout_2.setWidget(0, QtGui.QFormLayout.FieldRole, self.txt_title)
        self.label_2 = QtGui.QLabel(self.layoutWidget3)
        self.label_2.setObjectName("label_2")
        self.formLayout_2.setWidget(1, QtGui.QFormLayout.LabelRole, self.label_2)
        self.txt_comment = QtGui.QPlainTextEdit(self.layoutWidget3)
        self.txt_comment.setObjectName("txt_comment")
        self.formLayout_2.setWidget(1, QtGui.QFormLayout.FieldRole, self.txt_comment)
        self.verticalLayout.addLayout(self.formLayout_2)
        self.horizontalLayout_11 = QtGui.QHBoxLayout()
        self.horizontalLayout_11.setObjectName("horizontalLayout_11")
        self.label_24 = QtGui.QLabel(self.layoutWidget3)
        self.label_24.setObjectName("label_24")
        self.horizontalLayout_11.addWidget(self.label_24)
        self.txt_width = QtGui.QLineEdit(self.layoutWidget3)
        self.txt_width.setObjectName("txt_width")
        self.horizontalLayout_11.addWidget(self.txt_width)
        self.label_25 = QtGui.QLabel(self.layoutWidget3)
        self.label_25.setObjectName("label_25")
        self.horizontalLayout_11.addWidget(self.label_25)
        self.txt_height = QtGui.QLineEdit(self.layoutWidget3)
        self.txt_height.setObjectName("txt_height")
        self.horizontalLayout_11.addWidget(self.txt_height)
        self.btn_winsize = QtGui.QPushButton(self.layoutWidget3)
        self.btn_winsize.setObjectName("btn_winsize")
        self.horizontalLayout_11.addWidget(self.btn_winsize)
        self.verticalLayout.addLayout(self.horizontalLayout_11)
        self.horizontalLayout_4 = QtGui.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.check_auto_update = QtGui.QCheckBox(self.layoutWidget3)
        self.check_auto_update.setChecked(True)
        self.check_auto_update.setObjectName("check_auto_update")
        self.horizontalLayout_4.addWidget(self.check_auto_update)
        self.check_trans = QtGui.QCheckBox(self.layoutWidget3)
        self.check_trans.setChecked(False)
        self.check_trans.setObjectName("check_trans")
        self.horizontalLayout_4.addWidget(self.check_trans)
        self.verticalLayout.addLayout(self.horizontalLayout_4)
        self.horizontalLayout_16 = QtGui.QHBoxLayout()
        self.horizontalLayout_16.setObjectName("horizontalLayout_16")
        self.label_27 = QtGui.QLabel(self.layoutWidget3)
        self.label_27.setObjectName("label_27")
        self.horizontalLayout_16.addWidget(self.label_27)
        self.rb_isAveSlice = QtGui.QRadioButton(self.layoutWidget3)
        self.rb_isAveSlice.setChecked(True)
        self.rb_isAveSlice.setObjectName("rb_isAveSlice")
        self.horizontalLayout_16.addWidget(self.rb_isAveSlice)
        self.rb_isSumSlice = QtGui.QRadioButton(self.layoutWidget3)
        self.rb_isSumSlice.setObjectName("rb_isSumSlice")
        self.horizontalLayout_16.addWidget(self.rb_isSumSlice)
        self.verticalLayout.addLayout(self.horizontalLayout_16)
        self.tabWidget_2.addTab(self.tab_3, "")
        self.tab_4 = QtGui.QWidget()
        self.tab_4.setObjectName("tab_4")
        self.verticalLayoutWidget_2 = QtGui.QWidget(self.tab_4)
        self.verticalLayoutWidget_2.setGeometry(QtCore.QRect(10, 10, 401, 241))
        self.verticalLayoutWidget_2.setObjectName("verticalLayoutWidget_2")
        self.verticalLayout_4 = QtGui.QVBoxLayout(self.verticalLayoutWidget_2)
        self.verticalLayout_4.setSizeConstraint(QtGui.QLayout.SetNoConstraint)
        self.verticalLayout_4.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.grp_grid_h = QtGui.QGroupBox(self.verticalLayoutWidget_2)
        self.grp_grid_h.setEnabled(True)
        self.grp_grid_h.setCheckable(True)
        self.grp_grid_h.setObjectName("grp_grid_h")
        self.gridLayoutWidget_2 = QtGui.QWidget(self.grp_grid_h)
        self.gridLayoutWidget_2.setGeometry(QtCore.QRect(9, 20, 381, 71))
        self.gridLayoutWidget_2.setObjectName("gridLayoutWidget_2")
        self.gridLayout_2 = QtGui.QGridLayout(self.gridLayoutWidget_2)
        self.gridLayout_2.setSizeConstraint(QtGui.QLayout.SetNoConstraint)
        self.gridLayout_2.setSpacing(0)
        self.gridLayout_2.setContentsMargins(0, -1, -1, -1)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.label_31 = QtGui.QLabel(self.gridLayoutWidget_2)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_31.sizePolicy().hasHeightForWidth())
        self.label_31.setSizePolicy(sizePolicy)
        self.label_31.setMaximumSize(QtCore.QSize(60, 16777215))
        self.label_31.setObjectName("label_31")
        self.gridLayout_2.addWidget(self.label_31, 0, 0, 1, 1)
        self.txt_h_interval = QtGui.QLineEdit(self.gridLayoutWidget_2)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txt_h_interval.sizePolicy().hasHeightForWidth())
        self.txt_h_interval.setSizePolicy(sizePolicy)
        self.txt_h_interval.setMaximumSize(QtCore.QSize(60, 16777215))
        self.txt_h_interval.setObjectName("txt_h_interval")
        self.gridLayout_2.addWidget(self.txt_h_interval, 1, 4, 1, 1)
        self.txt_grid_width_h = QtGui.QLineEdit(self.gridLayoutWidget_2)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txt_grid_width_h.sizePolicy().hasHeightForWidth())
        self.txt_grid_width_h.setSizePolicy(sizePolicy)
        self.txt_grid_width_h.setMaximumSize(QtCore.QSize(60, 16777215))
        self.txt_grid_width_h.setMaxLength(3)
        self.txt_grid_width_h.setObjectName("txt_grid_width_h")
        self.gridLayout_2.addWidget(self.txt_grid_width_h, 0, 4, 1, 1)
        self.cb_grid_color_h = QtGui.QComboBox(self.gridLayoutWidget_2)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cb_grid_color_h.sizePolicy().hasHeightForWidth())
        self.cb_grid_color_h.setSizePolicy(sizePolicy)
        self.cb_grid_color_h.setMaximumSize(QtCore.QSize(80, 16777215))
        self.cb_grid_color_h.setObjectName("cb_grid_color_h")
        self.gridLayout_2.addWidget(self.cb_grid_color_h, 0, 1, 1, 1)
        self.label_32 = QtGui.QLabel(self.gridLayoutWidget_2)
        self.label_32.setMaximumSize(QtCore.QSize(60, 16777215))
        self.label_32.setObjectName("label_32")
        self.gridLayout_2.addWidget(self.label_32, 1, 0, 1, 1)
        self.cb_grid_style_h = QtGui.QComboBox(self.gridLayoutWidget_2)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cb_grid_style_h.sizePolicy().hasHeightForWidth())
        self.cb_grid_style_h.setSizePolicy(sizePolicy)
        self.cb_grid_style_h.setMaximumSize(QtCore.QSize(80, 16777215))
        self.cb_grid_style_h.setObjectName("cb_grid_style_h")
        self.gridLayout_2.addWidget(self.cb_grid_style_h, 1, 1, 1, 1)
        self.label_15 = QtGui.QLabel(self.gridLayoutWidget_2)
        self.label_15.setMaximumSize(QtCore.QSize(60, 16777215))
        self.label_15.setObjectName("label_15")
        self.gridLayout_2.addWidget(self.label_15, 1, 3, 1, 1)
        spacerItem4 = QtGui.QSpacerItem(20, 20, QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Minimum)
        self.gridLayout_2.addItem(spacerItem4, 0, 2, 1, 1)
        self.label_33 = QtGui.QLabel(self.gridLayoutWidget_2)
        self.label_33.setMaximumSize(QtCore.QSize(60, 16777215))
        self.label_33.setObjectName("label_33")
        self.gridLayout_2.addWidget(self.label_33, 0, 3, 1, 1)
        self.verticalLayout_4.addWidget(self.grp_grid_h)
        self.grp_grid_v = QtGui.QGroupBox(self.verticalLayoutWidget_2)
        self.grp_grid_v.setEnabled(True)
        self.grp_grid_v.setCheckable(True)
        self.grp_grid_v.setObjectName("grp_grid_v")
        self.gridLayoutWidget_3 = QtGui.QWidget(self.grp_grid_v)
        self.gridLayoutWidget_3.setGeometry(QtCore.QRect(10, 20, 381, 75))
        self.gridLayoutWidget_3.setObjectName("gridLayoutWidget_3")
        self.gridLayout_3 = QtGui.QGridLayout(self.gridLayoutWidget_3)
        self.gridLayout_3.setSizeConstraint(QtGui.QLayout.SetNoConstraint)
        self.gridLayout_3.setSpacing(0)
        self.gridLayout_3.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.cb_grid_color_v = QtGui.QComboBox(self.gridLayoutWidget_3)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cb_grid_color_v.sizePolicy().hasHeightForWidth())
        self.cb_grid_color_v.setSizePolicy(sizePolicy)
        self.cb_grid_color_v.setMaximumSize(QtCore.QSize(80, 16777215))
        self.cb_grid_color_v.setObjectName("cb_grid_color_v")
        self.gridLayout_3.addWidget(self.cb_grid_color_v, 0, 1, 1, 1)
        self.cb_grid_style_v = QtGui.QComboBox(self.gridLayoutWidget_3)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.cb_grid_style_v.sizePolicy().hasHeightForWidth())
        self.cb_grid_style_v.setSizePolicy(sizePolicy)
        self.cb_grid_style_v.setMaximumSize(QtCore.QSize(80, 16777215))
        self.cb_grid_style_v.setObjectName("cb_grid_style_v")
        self.gridLayout_3.addWidget(self.cb_grid_style_v, 1, 1, 1, 1)
        self.label_36 = QtGui.QLabel(self.gridLayoutWidget_3)
        self.label_36.setMaximumSize(QtCore.QSize(60, 16777215))
        self.label_36.setObjectName("label_36")
        self.gridLayout_3.addWidget(self.label_36, 0, 3, 1, 1)
        self.txt_grid_width_v = QtGui.QLineEdit(self.gridLayoutWidget_3)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txt_grid_width_v.sizePolicy().hasHeightForWidth())
        self.txt_grid_width_v.setSizePolicy(sizePolicy)
        self.txt_grid_width_v.setMaximumSize(QtCore.QSize(60, 16777215))
        self.txt_grid_width_v.setMaxLength(3)
        self.txt_grid_width_v.setObjectName("txt_grid_width_v")
        self.gridLayout_3.addWidget(self.txt_grid_width_v, 0, 4, 1, 1)
        self.label_16 = QtGui.QLabel(self.gridLayoutWidget_3)
        self.label_16.setMaximumSize(QtCore.QSize(60, 16777215))
        self.label_16.setObjectName("label_16")
        self.gridLayout_3.addWidget(self.label_16, 1, 3, 1, 1)
        self.txt_v_interval = QtGui.QLineEdit(self.gridLayoutWidget_3)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txt_v_interval.sizePolicy().hasHeightForWidth())
        self.txt_v_interval.setSizePolicy(sizePolicy)
        self.txt_v_interval.setMaximumSize(QtCore.QSize(60, 16777215))
        self.txt_v_interval.setObjectName("txt_v_interval")
        self.gridLayout_3.addWidget(self.txt_v_interval, 1, 4, 1, 1)
        spacerItem5 = QtGui.QSpacerItem(20, 20, QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Minimum)
        self.gridLayout_3.addItem(spacerItem5, 0, 2, 1, 1)
        self.label_35 = QtGui.QLabel(self.gridLayoutWidget_3)
        self.label_35.setMaximumSize(QtCore.QSize(60, 16777215))
        self.label_35.setObjectName("label_35")
        self.gridLayout_3.addWidget(self.label_35, 0, 0, 1, 1)
        self.label_34 = QtGui.QLabel(self.gridLayoutWidget_3)
        self.label_34.setMaximumSize(QtCore.QSize(60, 16777215))
        self.label_34.setObjectName("label_34")
        self.gridLayout_3.addWidget(self.label_34, 1, 0, 1, 1)
        self.verticalLayout_4.addWidget(self.grp_grid_v)
        self.check_bank_separator = QtGui.QCheckBox(self.verticalLayoutWidget_2)
        self.check_bank_separator.setEnabled(False)
        self.check_bank_separator.setObjectName("check_bank_separator")
        self.verticalLayout_4.addWidget(self.check_bank_separator)
        self.tabWidget_2.addTab(self.tab_4, "")
        self.tab_5 = QtGui.QWidget()
        self.tab_5.setObjectName("tab_5")
        self.verticalLayoutWidget = QtGui.QWidget(self.tab_5)
        self.verticalLayoutWidget.setGeometry(QtCore.QRect(10, 10, 401, 123))
        self.verticalLayoutWidget.setObjectName("verticalLayoutWidget")
        self.verticalLayout_5 = QtGui.QVBoxLayout(self.verticalLayoutWidget)
        self.verticalLayout_5.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.horizontalLayout_12 = QtGui.QHBoxLayout()
        self.horizontalLayout_12.setObjectName("horizontalLayout_12")
        self.formLayout_6 = QtGui.QFormLayout()
        self.formLayout_6.setObjectName("formLayout_6")
        self.label_18 = QtGui.QLabel(self.verticalLayoutWidget)
        self.label_18.setObjectName("label_18")
        self.formLayout_6.setWidget(0, QtGui.QFormLayout.LabelRole, self.label_18)
        self.cb_cmap = QtGui.QComboBox(self.verticalLayoutWidget)
        self.cb_cmap.setObjectName("cb_cmap")
        self.formLayout_6.setWidget(0, QtGui.QFormLayout.FieldRole, self.cb_cmap)
        self.horizontalLayout_12.addLayout(self.formLayout_6)
        self.check_cmap_log = QtGui.QCheckBox(self.verticalLayoutWidget)
        self.check_cmap_log.setObjectName("check_cmap_log")
        self.horizontalLayout_12.addWidget(self.check_cmap_log)
        self.verticalLayout_5.addLayout(self.horizontalLayout_12)
        self.horizontalLayout_15 = QtGui.QHBoxLayout()
        self.horizontalLayout_15.setObjectName("horizontalLayout_15")
        self.check_smooth = QtGui.QCheckBox(self.verticalLayoutWidget)
        self.check_smooth.setObjectName("check_smooth")
        self.horizontalLayout_15.addWidget(self.check_smooth)
        self.label_26 = QtGui.QLabel(self.verticalLayoutWidget)
        self.label_26.setEnabled(False)
        self.label_26.setObjectName("label_26")
        self.horizontalLayout_15.addWidget(self.label_26)
        self.txt_smooth_window = QtGui.QLineEdit(self.verticalLayoutWidget)
        self.txt_smooth_window.setEnabled(False)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txt_smooth_window.sizePolicy().hasHeightForWidth())
        self.txt_smooth_window.setSizePolicy(sizePolicy)
        self.txt_smooth_window.setContextMenuPolicy(QtCore.Qt.DefaultContextMenu)
        self.txt_smooth_window.setObjectName("txt_smooth_window")
        self.horizontalLayout_15.addWidget(self.txt_smooth_window)
        self.label_28 = QtGui.QLabel(self.verticalLayoutWidget)
        self.label_28.setEnabled(False)
        self.label_28.setObjectName("label_28")
        self.horizontalLayout_15.addWidget(self.label_28)
        self.txt_smooth_times = QtGui.QLineEdit(self.verticalLayoutWidget)
        self.txt_smooth_times.setEnabled(False)
        self.txt_smooth_times.setObjectName("txt_smooth_times")
        self.horizontalLayout_15.addWidget(self.txt_smooth_times)
        spacerItem6 = QtGui.QSpacerItem(40, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.horizontalLayout_15.addItem(spacerItem6)
        self.verticalLayout_5.addLayout(self.horizontalLayout_15)
        self.horizontalLayout_13 = QtGui.QHBoxLayout()
        self.horizontalLayout_13.setSizeConstraint(QtGui.QLayout.SetNoConstraint)
        self.horizontalLayout_13.setObjectName("horizontalLayout_13")
        self.check_cmap_auto_range = QtGui.QCheckBox(self.verticalLayoutWidget)
        self.check_cmap_auto_range.setChecked(True)
        self.check_cmap_auto_range.setObjectName("check_cmap_auto_range")
        self.horizontalLayout_13.addWidget(self.check_cmap_auto_range)
        self.horizontalLayout_14 = QtGui.QHBoxLayout()
        self.horizontalLayout_14.setObjectName("horizontalLayout_14")
        self.label_19 = QtGui.QLabel(self.verticalLayoutWidget)
        self.label_19.setEnabled(False)
        self.label_19.setObjectName("label_19")
        self.horizontalLayout_14.addWidget(self.label_19)
        self.txt_cmap_min = QtGui.QLineEdit(self.verticalLayoutWidget)
        self.txt_cmap_min.setEnabled(False)
        self.txt_cmap_min.setObjectName("txt_cmap_min")
        self.horizontalLayout_14.addWidget(self.txt_cmap_min)
        self.label_20 = QtGui.QLabel(self.verticalLayoutWidget)
        self.label_20.setEnabled(False)
        self.label_20.setObjectName("label_20")
        self.horizontalLayout_14.addWidget(self.label_20)
        self.txt_cmap_max = QtGui.QLineEdit(self.verticalLayoutWidget)
        self.txt_cmap_max.setEnabled(False)
        self.txt_cmap_max.setObjectName("txt_cmap_max")
        self.horizontalLayout_14.addWidget(self.txt_cmap_max)
        self.horizontalLayout_13.addLayout(self.horizontalLayout_14)
        self.verticalLayout_5.addLayout(self.horizontalLayout_13)
        self.slider_cmap = QtGui.QSlider(self.tab_5)
        self.slider_cmap.setEnabled(False)
        self.slider_cmap.setGeometry(QtCore.QRect(10, 120, 401, 19))
        self.slider_cmap.setMaximum(100)
        self.slider_cmap.setProperty("value", 100)
        self.slider_cmap.setOrientation(QtCore.Qt.Horizontal)
        self.slider_cmap.setTickPosition(QtGui.QSlider.TicksBelow)
        self.slider_cmap.setTickInterval(50)
        self.slider_cmap.setObjectName("slider_cmap")
        self.label_21 = QtGui.QLabel(self.tab_5)
        self.label_21.setEnabled(False)
        self.label_21.setGeometry(QtCore.QRect(10, 140, 19, 12))
        self.label_21.setObjectName("label_21")
        self.label_22 = QtGui.QLabel(self.tab_5)
        self.label_22.setEnabled(False)
        self.label_22.setGeometry(QtCore.QRect(200, 140, 31, 20))
        self.label_22.setObjectName("label_22")
        self.label_23 = QtGui.QLabel(self.tab_5)
        self.label_23.setEnabled(False)
        self.label_23.setGeometry(QtCore.QRect(370, 140, 41, 20))
        self.label_23.setObjectName("label_23")
        self.tabWidget_2.addTab(self.tab_5, "")
        self.tab_6 = QtGui.QWidget()
        self.tab_6.setObjectName("tab_6")
        self.lb_TF_MaskColor = QtGui.QLabel(self.tab_6)
        self.lb_TF_MaskColor.setGeometry(QtCore.QRect(10, 15, 101, 17))
        self.lb_TF_MaskColor.setObjectName("lb_TF_MaskColor")
        self.lb_TF_BGColor = QtGui.QLabel(self.tab_6)
        self.lb_TF_BGColor.setGeometry(QtCore.QRect(240, 15, 81, 17))
        self.lb_TF_BGColor.setObjectName("lb_TF_BGColor")
        self.cb_TF_MaskColor = QtGui.QComboBox(self.tab_6)
        self.cb_TF_MaskColor.setGeometry(QtCore.QRect(110, 10, 85, 27))
        self.cb_TF_MaskColor.setObjectName("cb_TF_MaskColor")
        self.cb_TF_MaskColor.addItem("")
        self.cb_TF_MaskColor.addItem("")
        self.cb_TF_BGColor = QtGui.QComboBox(self.tab_6)
        self.cb_TF_BGColor.setGeometry(QtCore.QRect(320, 10, 85, 27))
        self.cb_TF_BGColor.setObjectName("cb_TF_BGColor")
        self.cb_TF_BGColor.addItem("")
        self.cb_TF_BGColor.addItem("")
        self.ch_TF_TopSideTicks = QtGui.QCheckBox(self.tab_6)
        self.ch_TF_TopSideTicks.setGeometry(QtCore.QRect(160, 60, 61, 22))
        self.ch_TF_TopSideTicks.setObjectName("ch_TF_TopSideTicks")
        self.ch_TF_RightSideTicks = QtGui.QCheckBox(self.tab_6)
        self.ch_TF_RightSideTicks.setGeometry(QtCore.QRect(160, 80, 61, 22))
        self.ch_TF_RightSideTicks.setObjectName("ch_TF_RightSideTicks")
        self.lb_TF_AddTicks = QtGui.QLabel(self.tab_6)
        self.lb_TF_AddTicks.setGeometry(QtCore.QRect(10, 63, 101, 17))
        self.lb_TF_AddTicks.setObjectName("lb_TF_AddTicks")
        self.lb_TF_TicksColor = QtGui.QLabel(self.tab_6)
        self.lb_TF_TicksColor.setGeometry(QtCore.QRect(240, 63, 81, 17))
        self.lb_TF_TicksColor.setObjectName("lb_TF_TicksColor")
        self.cb_TF_TicksColor = QtGui.QComboBox(self.tab_6)
        self.cb_TF_TicksColor.setGeometry(QtCore.QRect(320, 60, 85, 27))
        self.cb_TF_TicksColor.setObjectName("cb_TF_TicksColor")
        self.cb_TF_TicksColor.addItem("")
        self.cb_TF_TicksColor.addItem("")
        self.lb_TF_MajorTicks = QtGui.QLabel(self.tab_6)
        self.lb_TF_MajorTicks.setGeometry(QtCore.QRect(30, 120, 91, 17))
        self.lb_TF_MajorTicks.setObjectName("lb_TF_MajorTicks")
        self.lb_TF_MajorTicks_L = QtGui.QLabel(self.tab_6)
        self.lb_TF_MajorTicks_L.setGeometry(QtCore.QRect(140, 120, 68, 17))
        self.lb_TF_MajorTicks_L.setObjectName("lb_TF_MajorTicks_L")
        self.lb_TF_MajorTicks_W = QtGui.QLabel(self.tab_6)
        self.lb_TF_MajorTicks_W.setGeometry(QtCore.QRect(280, 120, 68, 17))
        self.lb_TF_MajorTicks_W.setObjectName("lb_TF_MajorTicks_W")
        self.ch_TF_MinorTicks = QtGui.QCheckBox(self.tab_6)
        self.ch_TF_MinorTicks.setGeometry(QtCore.QRect(10, 150, 121, 22))
        self.ch_TF_MinorTicks.setObjectName("ch_TF_MinorTicks")
        self.txt_TF_MajorTicks_L = QtGui.QLineEdit(self.tab_6)
        self.txt_TF_MajorTicks_L.setGeometry(QtCore.QRect(210, 115, 51, 27))
        self.txt_TF_MajorTicks_L.setObjectName("txt_TF_MajorTicks_L")
        self.txt_TF_MajorTicks_W = QtGui.QLineEdit(self.tab_6)
        self.txt_TF_MajorTicks_W.setGeometry(QtCore.QRect(340, 115, 51, 27))
        self.txt_TF_MajorTicks_W.setObjectName("txt_TF_MajorTicks_W")
        self.txt_TF_MinorTicks_L = QtGui.QLineEdit(self.tab_6)
        self.txt_TF_MinorTicks_L.setEnabled(False)
        self.txt_TF_MinorTicks_L.setGeometry(QtCore.QRect(210, 150, 51, 27))
        self.txt_TF_MinorTicks_L.setObjectName("txt_TF_MinorTicks_L")
        self.txt_TF_MinorTicks_W = QtGui.QLineEdit(self.tab_6)
        self.txt_TF_MinorTicks_W.setEnabled(False)
        self.txt_TF_MinorTicks_W.setGeometry(QtCore.QRect(340, 150, 51, 27))
        self.txt_TF_MinorTicks_W.setObjectName("txt_TF_MinorTicks_W")
        self.txt_TF_FrameLine_W = QtGui.QLineEdit(self.tab_6)
        self.txt_TF_FrameLine_W.setGeometry(QtCore.QRect(210, 190, 51, 27))
        self.txt_TF_FrameLine_W.setObjectName("txt_TF_FrameLine_W")
        self.lb_TF_MinorTicks_L = QtGui.QLabel(self.tab_6)
        self.lb_TF_MinorTicks_L.setGeometry(QtCore.QRect(140, 152, 68, 17))
        self.lb_TF_MinorTicks_L.setObjectName("lb_TF_MinorTicks_L")
        self.lb_TF_MinorTicks_W = QtGui.QLabel(self.tab_6)
        self.lb_TF_MinorTicks_W.setGeometry(QtCore.QRect(280, 152, 68, 17))
        self.lb_TF_MinorTicks_W.setObjectName("lb_TF_MinorTicks_W")
        self.lb_TF_FrameLine_W = QtGui.QLabel(self.tab_6)
        self.lb_TF_FrameLine_W.setGeometry(QtCore.QRect(60, 192, 151, 17))
        self.lb_TF_FrameLine_W.setObjectName("lb_TF_FrameLine_W")
        self.line = QtGui.QFrame(self.tab_6)
        self.line.setGeometry(QtCore.QRect(20, 40, 381, 20))
        self.line.setFrameShape(QtGui.QFrame.HLine)
        self.line.setFrameShadow(QtGui.QFrame.Sunken)
        self.line.setObjectName("line")
        self.ch_TF_BottomSideTicks = QtGui.QCheckBox(self.tab_6)
        self.ch_TF_BottomSideTicks.setGeometry(QtCore.QRect(80, 60, 71, 22))
        self.ch_TF_BottomSideTicks.setChecked(True)
        self.ch_TF_BottomSideTicks.setTristate(False)
        self.ch_TF_BottomSideTicks.setObjectName("ch_TF_BottomSideTicks")
        self.ch_TF_LeftSideTicks = QtGui.QCheckBox(self.tab_6)
        self.ch_TF_LeftSideTicks.setGeometry(QtCore.QRect(80, 80, 61, 22))
        self.ch_TF_LeftSideTicks.setChecked(True)
        self.ch_TF_LeftSideTicks.setObjectName("ch_TF_LeftSideTicks")
        self.tabWidget_2.addTab(self.tab_6, "")
        self.tab_7 = QtGui.QWidget()
        self.tab_7.setObjectName("tab_7")
        self.gridLayoutWidget_10 = QtGui.QWidget(self.tab_7)
        self.gridLayoutWidget_10.setGeometry(QtCore.QRect(10, 10, 331, 231))
        self.gridLayoutWidget_10.setObjectName("gridLayoutWidget_10")
        self.gridLayout_10 = QtGui.QGridLayout(self.gridLayoutWidget_10)
        self.gridLayout_10.setSizeConstraint(QtGui.QLayout.SetMinimumSize)
        self.gridLayout_10.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_10.setObjectName("gridLayout_10")
        self.txt_fs_y = QtGui.QLineEdit(self.gridLayoutWidget_10)
        self.txt_fs_y.setMaximumSize(QtCore.QSize(40, 22))
        self.txt_fs_y.setMaxLength(2)
        self.txt_fs_y.setObjectName("txt_fs_y")
        self.gridLayout_10.addWidget(self.txt_fs_y, 4, 2, 1, 1)
        self.label_50 = QtGui.QLabel(self.gridLayoutWidget_10)
        self.label_50.setMaximumSize(QtCore.QSize(16777215, 20))
        self.label_50.setObjectName("label_50")
        self.gridLayout_10.addWidget(self.label_50, 0, 4, 1, 1)
        self.cb_ft_xticks = QtGui.QComboBox(self.gridLayoutWidget_10)
        self.cb_ft_xticks.setMaximumSize(QtCore.QSize(16777215, 22))
        self.cb_ft_xticks.setObjectName("cb_ft_xticks")
        self.gridLayout_10.addWidget(self.cb_ft_xticks, 5, 4, 1, 1)
        self.label_48 = QtGui.QLabel(self.gridLayoutWidget_10)
        self.label_48.setMaximumSize(QtCore.QSize(16777215, 22))
        self.label_48.setObjectName("label_48")
        self.gridLayout_10.addWidget(self.label_48, 1, 0, 1, 1)
        self.txt_fs_title = QtGui.QLineEdit(self.gridLayoutWidget_10)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.txt_fs_title.sizePolicy().hasHeightForWidth())
        self.txt_fs_title.setSizePolicy(sizePolicy)
        self.txt_fs_title.setMaximumSize(QtCore.QSize(40, 22))
        self.txt_fs_title.setMaxLength(2)
        self.txt_fs_title.setObjectName("txt_fs_title")
        self.gridLayout_10.addWidget(self.txt_fs_title, 1, 2, 1, 1)
        self.cb_ft_x = QtGui.QComboBox(self.gridLayoutWidget_10)
        self.cb_ft_x.setMaximumSize(QtCore.QSize(16777215, 22))
        self.cb_ft_x.setObjectName("cb_ft_x")
        self.gridLayout_10.addWidget(self.cb_ft_x, 3, 4, 1, 1)
        self.txt_fs_x = QtGui.QLineEdit(self.gridLayoutWidget_10)
        self.txt_fs_x.setMaximumSize(QtCore.QSize(40, 22))
        self.txt_fs_x.setMaxLength(2)
        self.txt_fs_x.setObjectName("txt_fs_x")
        self.gridLayout_10.addWidget(self.txt_fs_x, 3, 2, 1, 1)
        self.txt_fs_comment = QtGui.QLineEdit(self.gridLayoutWidget_10)
        self.txt_fs_comment.setMaximumSize(QtCore.QSize(40, 22))
        self.txt_fs_comment.setMaxLength(2)
        self.txt_fs_comment.setObjectName("txt_fs_comment")
        self.gridLayout_10.addWidget(self.txt_fs_comment, 2, 2, 1, 1)
        self.cb_ft_title = QtGui.QComboBox(self.gridLayoutWidget_10)
        self.cb_ft_title.setMaximumSize(QtCore.QSize(16777215, 22))
        self.cb_ft_title.setObjectName("cb_ft_title")
        self.gridLayout_10.addWidget(self.cb_ft_title, 1, 4, 1, 1)
        self.label_49 = QtGui.QLabel(self.gridLayoutWidget_10)
        self.label_49.setMaximumSize(QtCore.QSize(16777215, 20))
        self.label_49.setObjectName("label_49")
        self.gridLayout_10.addWidget(self.label_49, 0, 2, 1, 1)
        spacerItem7 = QtGui.QSpacerItem(10, 20, QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Minimum)
        self.gridLayout_10.addItem(spacerItem7, 0, 1, 1, 1)
        self.cb_ft_comment = QtGui.QComboBox(self.gridLayoutWidget_10)
        self.cb_ft_comment.setMaximumSize(QtCore.QSize(16777215, 22))
        self.cb_ft_comment.setObjectName("cb_ft_comment")
        self.gridLayout_10.addWidget(self.cb_ft_comment, 2, 4, 1, 1)
        self.label_17 = QtGui.QLabel(self.gridLayoutWidget_10)
        self.label_17.setMaximumSize(QtCore.QSize(16777215, 22))
        self.label_17.setObjectName("label_17")
        self.gridLayout_10.addWidget(self.label_17, 2, 0, 1, 1)
        self.cb_ft_yticks = QtGui.QComboBox(self.gridLayoutWidget_10)
        self.cb_ft_yticks.setMaximumSize(QtCore.QSize(16777215, 22))
        self.cb_ft_yticks.setObjectName("cb_ft_yticks")
        self.gridLayout_10.addWidget(self.cb_ft_yticks, 6, 4, 1, 1)
        spacerItem8 = QtGui.QSpacerItem(140, 20, QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Minimum)
        self.gridLayout_10.addItem(spacerItem8, 0, 0, 1, 1)
        self.cb_ft_y = QtGui.QComboBox(self.gridLayoutWidget_10)
        self.cb_ft_y.setMaximumSize(QtCore.QSize(16777215, 22))
        self.cb_ft_y.setObjectName("cb_ft_y")
        self.gridLayout_10.addWidget(self.cb_ft_y, 4, 4, 1, 1)
        self.txt_fs_xticks = QtGui.QLineEdit(self.gridLayoutWidget_10)
        self.txt_fs_xticks.setMaximumSize(QtCore.QSize(40, 22))
        self.txt_fs_xticks.setMaxLength(2)
        self.txt_fs_xticks.setObjectName("txt_fs_xticks")
        self.gridLayout_10.addWidget(self.txt_fs_xticks, 5, 2, 1, 1)
        self.txt_fs_yticks = QtGui.QLineEdit(self.gridLayoutWidget_10)
        self.txt_fs_yticks.setMaximumSize(QtCore.QSize(40, 22))
        self.txt_fs_yticks.setMaxLength(2)
        self.txt_fs_yticks.setObjectName("txt_fs_yticks")
        self.gridLayout_10.addWidget(self.txt_fs_yticks, 6, 2, 1, 1)
        spacerItem9 = QtGui.QSpacerItem(10, 20, QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Minimum)
        self.gridLayout_10.addItem(spacerItem9, 0, 3, 1, 1)
        self.label_37 = QtGui.QLabel(self.gridLayoutWidget_10)
        self.label_37.setMaximumSize(QtCore.QSize(16777215, 22))
        self.label_37.setObjectName("label_37")
        self.gridLayout_10.addWidget(self.label_37, 3, 0, 1, 1)
        self.label_38 = QtGui.QLabel(self.gridLayoutWidget_10)
        self.label_38.setMaximumSize(QtCore.QSize(16777215, 22))
        self.label_38.setObjectName("label_38")
        self.gridLayout_10.addWidget(self.label_38, 4, 0, 1, 1)
        self.label_39 = QtGui.QLabel(self.gridLayoutWidget_10)
        self.label_39.setMaximumSize(QtCore.QSize(16777215, 22))
        self.label_39.setObjectName("label_39")
        self.gridLayout_10.addWidget(self.label_39, 5, 0, 1, 1)
        self.label_40 = QtGui.QLabel(self.gridLayoutWidget_10)
        self.label_40.setMaximumSize(QtCore.QSize(16777215, 22))
        self.label_40.setObjectName("label_40")
        self.gridLayout_10.addWidget(self.label_40, 6, 0, 1, 1)
        self.label_41 = QtGui.QLabel(self.gridLayoutWidget_10)
        self.label_41.setMaximumSize(QtCore.QSize(16777215, 22))
        self.label_41.setObjectName("label_41")
        self.gridLayout_10.addWidget(self.label_41, 7, 0, 1, 1)
        self.txt_fs_cbticks = QtGui.QLineEdit(self.gridLayoutWidget_10)
        self.txt_fs_cbticks.setMaximumSize(QtCore.QSize(40, 22))
        self.txt_fs_cbticks.setMaxLength(2)
        self.txt_fs_cbticks.setObjectName("txt_fs_cbticks")
        self.gridLayout_10.addWidget(self.txt_fs_cbticks, 7, 2, 1, 1)
        self.cb_ft_cbticks = QtGui.QComboBox(self.gridLayoutWidget_10)
        self.cb_ft_cbticks.setMaximumSize(QtCore.QSize(16777215, 22))
        self.cb_ft_cbticks.setObjectName("cb_ft_cbticks")
        self.gridLayout_10.addWidget(self.cb_ft_cbticks, 7, 4, 1, 1)
        self.tabWidget_2.addTab(self.tab_7, "")
        self.btn_close = QtGui.QPushButton(DlgViewPrms)
        self.btn_close.setGeometry(QtCore.QRect(270, 520, 51, 31))
        self.btn_close.setObjectName("btn_close")
        self.btn_apply = QtGui.QPushButton(DlgViewPrms)
        self.btn_apply.setGeometry(QtCore.QRect(330, 510, 101, 41))
        self.btn_apply.setObjectName("btn_apply")
        self.btn_backToInitial = QtGui.QPushButton(DlgViewPrms)
        self.btn_backToInitial.setGeometry(QtCore.QRect(160, 510, 61, 26))
        self.btn_backToInitial.setObjectName("btn_backToInitial")
        self.btn_backToDefault = QtGui.QPushButton(DlgViewPrms)
        self.btn_backToDefault.setGeometry(QtCore.QRect(90, 510, 61, 26))
        self.btn_backToDefault.setObjectName("btn_backToDefault")
        self.btn_saveAsDefault = QtGui.QPushButton(DlgViewPrms)
        self.btn_saveAsDefault.setGeometry(QtCore.QRect(90, 550, 61, 26))
        self.btn_saveAsDefault.setObjectName("btn_saveAsDefault")
        self.label_29 = QtGui.QLabel(DlgViewPrms)
        self.label_29.setGeometry(QtCore.QRect(20, 510, 68, 26))
        self.label_29.setObjectName("label_29")
        self.label_30 = QtGui.QLabel(DlgViewPrms)
        self.label_30.setGeometry(QtCore.QRect(20, 550, 68, 26))
        self.label_30.setObjectName("label_30")

        self.retranslateUi(DlgViewPrms)
        self.tabWidget.setCurrentIndex(0)
        self.combo_x_format.setCurrentIndex(-1)
        self.combo_y_format.setCurrentIndex(-1)
        self.tabWidget_2.setCurrentIndex(0)
        QtCore.QObject.connect(self.check_y_auto_range, QtCore.SIGNAL("toggled(bool)"), self.txt_y_min.setDisabled)
        QtCore.QObject.connect(self.check_y_auto_range, QtCore.SIGNAL("toggled(bool)"), self.txt_y_max.setDisabled)
        QtCore.QObject.connect(self.check_y_auto_range, QtCore.SIGNAL("toggled(bool)"), self.label_4.setDisabled)
        QtCore.QObject.connect(self.check_y_auto_range, QtCore.SIGNAL("toggled(bool)"), self.label_5.setDisabled)
        QtCore.QObject.connect(self.check_y_auto_tick, QtCore.SIGNAL("toggled(bool)"), self.label_6.setDisabled)
        QtCore.QObject.connect(self.check_y_auto_tick, QtCore.SIGNAL("toggled(bool)"), self.label_7.setDisabled)
        QtCore.QObject.connect(self.check_y_auto_tick, QtCore.SIGNAL("toggled(bool)"), self.spin_y_prec.setDisabled)
        QtCore.QObject.connect(self.check_x_auto_range, QtCore.SIGNAL("toggled(bool)"), self.txt_x_min.setDisabled)
        QtCore.QObject.connect(self.check_x_auto_range, QtCore.SIGNAL("toggled(bool)"), self.label_12.setDisabled)
        QtCore.QObject.connect(self.check_x_auto_range, QtCore.SIGNAL("toggled(bool)"), self.label_13.setDisabled)
        QtCore.QObject.connect(self.check_x_auto_range, QtCore.SIGNAL("toggled(bool)"), self.txt_x_max.setDisabled)
        QtCore.QObject.connect(self.check_x_auto_tick, QtCore.SIGNAL("toggled(bool)"), self.label_10.setDisabled)
        QtCore.QObject.connect(self.check_x_auto_tick, QtCore.SIGNAL("toggled(bool)"), self.spin_x_prec.setDisabled)
        QtCore.QObject.connect(self.check_x_auto_tick, QtCore.SIGNAL("toggled(bool)"), self.label_9.setDisabled)
        QtCore.QObject.connect(self.check_cmap_auto_range, QtCore.SIGNAL("toggled(bool)"), self.label_19.setDisabled)
        QtCore.QObject.connect(self.check_cmap_auto_range, QtCore.SIGNAL("toggled(bool)"), self.txt_cmap_min.setDisabled)
        QtCore.QObject.connect(self.check_cmap_auto_range, QtCore.SIGNAL("toggled(bool)"), self.label_20.setDisabled)
        QtCore.QObject.connect(self.check_cmap_auto_range, QtCore.SIGNAL("toggled(bool)"), self.txt_cmap_max.setDisabled)
        QtCore.QObject.connect(self.check_cmap_auto_range, QtCore.SIGNAL("toggled(bool)"), self.slider_cmap.setDisabled)
        QtCore.QObject.connect(self.check_cmap_auto_range, QtCore.SIGNAL("toggled(bool)"), self.label_21.setDisabled)
        QtCore.QObject.connect(self.check_cmap_auto_range, QtCore.SIGNAL("toggled(bool)"), self.label_22.setDisabled)
        QtCore.QObject.connect(self.check_cmap_auto_range, QtCore.SIGNAL("toggled(bool)"), self.label_23.setDisabled)
        QtCore.QObject.connect(self.check_x_auto_tick, QtCore.SIGNAL("toggled(bool)"), self.combo_x_format.setDisabled)
        QtCore.QObject.connect(self.check_y_auto_tick, QtCore.SIGNAL("toggled(bool)"), self.combo_y_format.setDisabled)
        QtCore.QObject.connect(self.check_smooth, QtCore.SIGNAL("toggled(bool)"), self.txt_smooth_window.setEnabled)
        QtCore.QObject.connect(self.check_smooth, QtCore.SIGNAL("toggled(bool)"), self.label_26.setEnabled)
        QtCore.QObject.connect(self.check_smooth, QtCore.SIGNAL("toggled(bool)"), self.label_28.setEnabled)
        QtCore.QObject.connect(self.check_smooth, QtCore.SIGNAL("toggled(bool)"), self.txt_smooth_times.setEnabled)
        QtCore.QObject.connect(self.ch_TF_MinorTicks, QtCore.SIGNAL("toggled(bool)"), self.txt_TF_MinorTicks_L.setEnabled)
        QtCore.QObject.connect(self.ch_TF_MinorTicks, QtCore.SIGNAL("toggled(bool)"), self.txt_TF_MinorTicks_W.setEnabled)
        QtCore.QMetaObject.connectSlotsByName(DlgViewPrms)
        DlgViewPrms.setTabOrder(self.tabWidget, self.txt_x_label)
        DlgViewPrms.setTabOrder(self.txt_x_label, self.txt_x_unit)
        DlgViewPrms.setTabOrder(self.txt_x_unit, self.check_x_log)
        DlgViewPrms.setTabOrder(self.check_x_log, self.check_x_inv)
        DlgViewPrms.setTabOrder(self.check_x_inv, self.check_x_auto_range)
        DlgViewPrms.setTabOrder(self.check_x_auto_range, self.txt_x_min)
        DlgViewPrms.setTabOrder(self.txt_x_min, self.txt_x_max)
        DlgViewPrms.setTabOrder(self.txt_x_max, self.check_x_auto_tick)
        DlgViewPrms.setTabOrder(self.check_x_auto_tick, self.combo_x_format)
        DlgViewPrms.setTabOrder(self.combo_x_format, self.spin_x_prec)
        DlgViewPrms.setTabOrder(self.spin_x_prec, self.check_y_log)
        DlgViewPrms.setTabOrder(self.check_y_log, self.check_y_inv)
        DlgViewPrms.setTabOrder(self.check_y_inv, self.check_y_auto_range)
        DlgViewPrms.setTabOrder(self.check_y_auto_range, self.txt_y_label)
        DlgViewPrms.setTabOrder(self.txt_y_label, self.txt_y_unit)
        DlgViewPrms.setTabOrder(self.txt_y_unit, self.txt_y_min)
        DlgViewPrms.setTabOrder(self.txt_y_min, self.txt_y_max)
        DlgViewPrms.setTabOrder(self.txt_y_max, self.check_y_auto_tick)
        DlgViewPrms.setTabOrder(self.check_y_auto_tick, self.combo_y_format)
        DlgViewPrms.setTabOrder(self.combo_y_format, self.spin_y_prec)
        DlgViewPrms.setTabOrder(self.spin_y_prec, self.btn_apply)
        DlgViewPrms.setTabOrder(self.btn_apply, self.btn_close)
        DlgViewPrms.setTabOrder(self.btn_close, self.tabWidget_2)
        DlgViewPrms.setTabOrder(self.tabWidget_2, self.txt_title)
        DlgViewPrms.setTabOrder(self.txt_title, self.txt_comment)
        DlgViewPrms.setTabOrder(self.txt_comment, self.txt_width)
        DlgViewPrms.setTabOrder(self.txt_width, self.txt_height)
        DlgViewPrms.setTabOrder(self.txt_height, self.btn_winsize)
        DlgViewPrms.setTabOrder(self.btn_winsize, self.check_auto_update)
        DlgViewPrms.setTabOrder(self.check_auto_update, self.check_trans)
        DlgViewPrms.setTabOrder(self.check_trans, self.rb_isAveSlice)
        DlgViewPrms.setTabOrder(self.rb_isAveSlice, self.rb_isSumSlice)
        DlgViewPrms.setTabOrder(self.rb_isSumSlice, self.grp_grid_h)
        DlgViewPrms.setTabOrder(self.grp_grid_h, self.cb_grid_color_h)
        DlgViewPrms.setTabOrder(self.cb_grid_color_h, self.txt_grid_width_h)
        DlgViewPrms.setTabOrder(self.txt_grid_width_h, self.cb_grid_style_h)
        DlgViewPrms.setTabOrder(self.cb_grid_style_h, self.txt_h_interval)
        DlgViewPrms.setTabOrder(self.txt_h_interval, self.grp_grid_v)
        DlgViewPrms.setTabOrder(self.grp_grid_v, self.cb_grid_color_v)
        DlgViewPrms.setTabOrder(self.cb_grid_color_v, self.txt_grid_width_v)
        DlgViewPrms.setTabOrder(self.txt_grid_width_v, self.cb_grid_style_v)
        DlgViewPrms.setTabOrder(self.cb_grid_style_v, self.txt_v_interval)
        DlgViewPrms.setTabOrder(self.txt_v_interval, self.check_bank_separator)
        DlgViewPrms.setTabOrder(self.check_bank_separator, self.cb_cmap)
        DlgViewPrms.setTabOrder(self.cb_cmap, self.check_cmap_log)
        DlgViewPrms.setTabOrder(self.check_cmap_log, self.check_smooth)
        DlgViewPrms.setTabOrder(self.check_smooth, self.txt_smooth_window)
        DlgViewPrms.setTabOrder(self.txt_smooth_window, self.txt_smooth_times)
        DlgViewPrms.setTabOrder(self.txt_smooth_times, self.check_cmap_auto_range)
        DlgViewPrms.setTabOrder(self.check_cmap_auto_range, self.txt_cmap_min)
        DlgViewPrms.setTabOrder(self.txt_cmap_min, self.txt_cmap_max)
        DlgViewPrms.setTabOrder(self.txt_cmap_max, self.slider_cmap)
        DlgViewPrms.setTabOrder(self.slider_cmap, self.cb_TF_MaskColor)
        DlgViewPrms.setTabOrder(self.cb_TF_MaskColor, self.cb_TF_BGColor)
        DlgViewPrms.setTabOrder(self.cb_TF_BGColor, self.ch_TF_BottomSideTicks)
        DlgViewPrms.setTabOrder(self.ch_TF_BottomSideTicks, self.ch_TF_LeftSideTicks)
        DlgViewPrms.setTabOrder(self.ch_TF_LeftSideTicks, self.ch_TF_TopSideTicks)
        DlgViewPrms.setTabOrder(self.ch_TF_TopSideTicks, self.ch_TF_RightSideTicks)
        DlgViewPrms.setTabOrder(self.ch_TF_RightSideTicks, self.cb_TF_TicksColor)
        DlgViewPrms.setTabOrder(self.cb_TF_TicksColor, self.ch_TF_MinorTicks)
        DlgViewPrms.setTabOrder(self.ch_TF_MinorTicks, self.txt_TF_MajorTicks_L)
        DlgViewPrms.setTabOrder(self.txt_TF_MajorTicks_L, self.txt_TF_MajorTicks_W)
        DlgViewPrms.setTabOrder(self.txt_TF_MajorTicks_W, self.txt_TF_MinorTicks_L)
        DlgViewPrms.setTabOrder(self.txt_TF_MinorTicks_L, self.txt_TF_MinorTicks_W)
        DlgViewPrms.setTabOrder(self.txt_TF_MinorTicks_W, self.txt_TF_FrameLine_W)
        DlgViewPrms.setTabOrder(self.txt_TF_FrameLine_W, self.txt_fs_title)
        DlgViewPrms.setTabOrder(self.txt_fs_title, self.cb_ft_title)
        DlgViewPrms.setTabOrder(self.cb_ft_title, self.txt_fs_comment)
        DlgViewPrms.setTabOrder(self.txt_fs_comment, self.cb_ft_comment)
        DlgViewPrms.setTabOrder(self.cb_ft_comment, self.txt_fs_x)
        DlgViewPrms.setTabOrder(self.txt_fs_x, self.cb_ft_x)
        DlgViewPrms.setTabOrder(self.cb_ft_x, self.txt_fs_y)
        DlgViewPrms.setTabOrder(self.txt_fs_y, self.cb_ft_y)
        DlgViewPrms.setTabOrder(self.cb_ft_y, self.txt_fs_xticks)
        DlgViewPrms.setTabOrder(self.txt_fs_xticks, self.cb_ft_xticks)
        DlgViewPrms.setTabOrder(self.cb_ft_xticks, self.txt_fs_yticks)
        DlgViewPrms.setTabOrder(self.txt_fs_yticks, self.cb_ft_yticks)
        DlgViewPrms.setTabOrder(self.cb_ft_yticks, self.txt_fs_cbticks)
        DlgViewPrms.setTabOrder(self.txt_fs_cbticks, self.cb_ft_cbticks)
        DlgViewPrms.setTabOrder(self.cb_ft_cbticks, self.btn_backToDefault)
        DlgViewPrms.setTabOrder(self.btn_backToDefault, self.btn_backToInitial)
        DlgViewPrms.setTabOrder(self.btn_backToInitial, self.btn_saveAsDefault)

    def retranslateUi(self, DlgViewPrms):
        DlgViewPrms.setWindowTitle(QtGui.QApplication.translate("DlgViewPrms", "Set View Parameters", None, QtGui.QApplication.UnicodeUTF8))
        self.check_x_auto_range.setText(QtGui.QApplication.translate("DlgViewPrms", "Auto Scale", None, QtGui.QApplication.UnicodeUTF8))
        self.label_12.setText(QtGui.QApplication.translate("DlgViewPrms", "Range", None, QtGui.QApplication.UnicodeUTF8))
        self.label_13.setText(QtGui.QApplication.translate("DlgViewPrms", "-", None, QtGui.QApplication.UnicodeUTF8))
        self.check_x_log.setText(QtGui.QApplication.translate("DlgViewPrms", "Log Scale", None, QtGui.QApplication.UnicodeUTF8))
        self.check_x_inv.setText(QtGui.QApplication.translate("DlgViewPrms", "Inversion", None, QtGui.QApplication.UnicodeUTF8))
        self.check_x_auto_tick.setText(QtGui.QApplication.translate("DlgViewPrms", "Auto Format", None, QtGui.QApplication.UnicodeUTF8))
        self.label_9.setText(QtGui.QApplication.translate("DlgViewPrms", "Format", None, QtGui.QApplication.UnicodeUTF8))
        self.label_10.setText(QtGui.QApplication.translate("DlgViewPrms", "Precision", None, QtGui.QApplication.UnicodeUTF8))
        self.label_8.setText(QtGui.QApplication.translate("DlgViewPrms", "Ticks Label Format", None, QtGui.QApplication.UnicodeUTF8))
        self.txt_x_label.setText(QtGui.QApplication.translate("DlgViewPrms", "X", None, QtGui.QApplication.UnicodeUTF8))
        self.label_14.setText(QtGui.QApplication.translate("DlgViewPrms", "Label", None, QtGui.QApplication.UnicodeUTF8))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("DlgViewPrms", "X Scale", None, QtGui.QApplication.UnicodeUTF8))
        self.check_y_auto_range.setText(QtGui.QApplication.translate("DlgViewPrms", "Auto Scale", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("DlgViewPrms", "Range", None, QtGui.QApplication.UnicodeUTF8))
        self.label_5.setText(QtGui.QApplication.translate("DlgViewPrms", "-", None, QtGui.QApplication.UnicodeUTF8))
        self.check_y_log.setText(QtGui.QApplication.translate("DlgViewPrms", "Log Scale", None, QtGui.QApplication.UnicodeUTF8))
        self.check_y_inv.setText(QtGui.QApplication.translate("DlgViewPrms", "Inversion", None, QtGui.QApplication.UnicodeUTF8))
        self.check_y_auto_tick.setText(QtGui.QApplication.translate("DlgViewPrms", "Auto Format", None, QtGui.QApplication.UnicodeUTF8))
        self.label_6.setText(QtGui.QApplication.translate("DlgViewPrms", "Format", None, QtGui.QApplication.UnicodeUTF8))
        self.label_7.setText(QtGui.QApplication.translate("DlgViewPrms", "Precision", None, QtGui.QApplication.UnicodeUTF8))
        self.label_11.setText(QtGui.QApplication.translate("DlgViewPrms", "Ticks Label Format", None, QtGui.QApplication.UnicodeUTF8))
        self.txt_y_label.setText(QtGui.QApplication.translate("DlgViewPrms", "Y", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("DlgViewPrms", "Label", None, QtGui.QApplication.UnicodeUTF8))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("DlgViewPrms", "Y Scale", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("DlgViewPrms", "Title", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("DlgViewPrms", "Comment", None, QtGui.QApplication.UnicodeUTF8))
        self.label_24.setText(QtGui.QApplication.translate("DlgViewPrms", "Main plot width", None, QtGui.QApplication.UnicodeUTF8))
        self.label_25.setText(QtGui.QApplication.translate("DlgViewPrms", "height", None, QtGui.QApplication.UnicodeUTF8))
        self.btn_winsize.setText(QtGui.QApplication.translate("DlgViewPrms", "Current", None, QtGui.QApplication.UnicodeUTF8))
        self.check_auto_update.setText(QtGui.QApplication.translate("DlgViewPrms", "Auto Update", None, QtGui.QApplication.UnicodeUTF8))
        self.check_trans.setText(QtGui.QApplication.translate("DlgViewPrms", "Transposition of the Axes", None, QtGui.QApplication.UnicodeUTF8))
        self.label_27.setText(QtGui.QApplication.translate("DlgViewPrms", "      Slice Mode :", None, QtGui.QApplication.UnicodeUTF8))
        self.rb_isAveSlice.setText(QtGui.QApplication.translate("DlgViewPrms", "Average", None, QtGui.QApplication.UnicodeUTF8))
        self.rb_isSumSlice.setText(QtGui.QApplication.translate("DlgViewPrms", "Summation", None, QtGui.QApplication.UnicodeUTF8))
        self.tabWidget_2.setTabText(self.tabWidget_2.indexOf(self.tab_3), QtGui.QApplication.translate("DlgViewPrms", "General", None, QtGui.QApplication.UnicodeUTF8))
        self.grp_grid_h.setTitle(QtGui.QApplication.translate("DlgViewPrms", "Horizontal", None, QtGui.QApplication.UnicodeUTF8))
        self.label_31.setText(QtGui.QApplication.translate("DlgViewPrms", "Color", None, QtGui.QApplication.UnicodeUTF8))
        self.txt_grid_width_h.setText(QtGui.QApplication.translate("DlgViewPrms", "0.5", None, QtGui.QApplication.UnicodeUTF8))
        self.label_32.setText(QtGui.QApplication.translate("DlgViewPrms", "Style", None, QtGui.QApplication.UnicodeUTF8))
        self.label_15.setText(QtGui.QApplication.translate("DlgViewPrms", "Interval", None, QtGui.QApplication.UnicodeUTF8))
        self.label_33.setText(QtGui.QApplication.translate("DlgViewPrms", "Width", None, QtGui.QApplication.UnicodeUTF8))
        self.grp_grid_v.setTitle(QtGui.QApplication.translate("DlgViewPrms", "Vertical", None, QtGui.QApplication.UnicodeUTF8))
        self.label_36.setText(QtGui.QApplication.translate("DlgViewPrms", "Width", None, QtGui.QApplication.UnicodeUTF8))
        self.txt_grid_width_v.setText(QtGui.QApplication.translate("DlgViewPrms", "0.5", None, QtGui.QApplication.UnicodeUTF8))
        self.label_16.setText(QtGui.QApplication.translate("DlgViewPrms", "Interval", None, QtGui.QApplication.UnicodeUTF8))
        self.label_35.setText(QtGui.QApplication.translate("DlgViewPrms", "Color", None, QtGui.QApplication.UnicodeUTF8))
        self.label_34.setText(QtGui.QApplication.translate("DlgViewPrms", "Style", None, QtGui.QApplication.UnicodeUTF8))
        self.check_bank_separator.setText(QtGui.QApplication.translate("DlgViewPrms", "Bank Separator", None, QtGui.QApplication.UnicodeUTF8))
        self.tabWidget_2.setTabText(self.tabWidget_2.indexOf(self.tab_4), QtGui.QApplication.translate("DlgViewPrms", "Grid", None, QtGui.QApplication.UnicodeUTF8))
        self.label_18.setText(QtGui.QApplication.translate("DlgViewPrms", "Color Map", None, QtGui.QApplication.UnicodeUTF8))
        self.check_cmap_log.setText(QtGui.QApplication.translate("DlgViewPrms", "Log Scale", None, QtGui.QApplication.UnicodeUTF8))
        self.check_smooth.setText(QtGui.QApplication.translate("DlgViewPrms", "Smoothing", None, QtGui.QApplication.UnicodeUTF8))
        self.label_26.setText(QtGui.QApplication.translate("DlgViewPrms", "Window", None, QtGui.QApplication.UnicodeUTF8))
        self.txt_smooth_window.setText(QtGui.QApplication.translate("DlgViewPrms", "1", None, QtGui.QApplication.UnicodeUTF8))
        self.label_28.setText(QtGui.QApplication.translate("DlgViewPrms", "Times", None, QtGui.QApplication.UnicodeUTF8))
        self.txt_smooth_times.setText(QtGui.QApplication.translate("DlgViewPrms", "1", None, QtGui.QApplication.UnicodeUTF8))
        self.check_cmap_auto_range.setText(QtGui.QApplication.translate("DlgViewPrms", "Auto Scale", None, QtGui.QApplication.UnicodeUTF8))
        self.label_19.setText(QtGui.QApplication.translate("DlgViewPrms", "Range", None, QtGui.QApplication.UnicodeUTF8))
        self.label_20.setText(QtGui.QApplication.translate("DlgViewPrms", "-", None, QtGui.QApplication.UnicodeUTF8))
        self.label_21.setText(QtGui.QApplication.translate("DlgViewPrms", "0%", None, QtGui.QApplication.UnicodeUTF8))
        self.label_22.setText(QtGui.QApplication.translate("DlgViewPrms", "50%", None, QtGui.QApplication.UnicodeUTF8))
        self.label_23.setText(QtGui.QApplication.translate("DlgViewPrms", "100%", None, QtGui.QApplication.UnicodeUTF8))
        self.tabWidget_2.setTabText(self.tabWidget_2.indexOf(self.tab_5), QtGui.QApplication.translate("DlgViewPrms", "Color Map", None, QtGui.QApplication.UnicodeUTF8))
        self.lb_TF_MaskColor.setText(QtGui.QApplication.translate("DlgViewPrms", "Mask Color :", None, QtGui.QApplication.UnicodeUTF8))
        self.lb_TF_BGColor.setText(QtGui.QApplication.translate("DlgViewPrms", "BG Color :", None, QtGui.QApplication.UnicodeUTF8))
        self.cb_TF_MaskColor.setItemText(0, QtGui.QApplication.translate("DlgViewPrms", "Black", None, QtGui.QApplication.UnicodeUTF8))
        self.cb_TF_MaskColor.setItemText(1, QtGui.QApplication.translate("DlgViewPrms", "White", None, QtGui.QApplication.UnicodeUTF8))
        self.cb_TF_BGColor.setItemText(0, QtGui.QApplication.translate("DlgViewPrms", "Black", None, QtGui.QApplication.UnicodeUTF8))
        self.cb_TF_BGColor.setItemText(1, QtGui.QApplication.translate("DlgViewPrms", "White", None, QtGui.QApplication.UnicodeUTF8))
        self.ch_TF_TopSideTicks.setText(QtGui.QApplication.translate("DlgViewPrms", "Top", None, QtGui.QApplication.UnicodeUTF8))
        self.ch_TF_RightSideTicks.setText(QtGui.QApplication.translate("DlgViewPrms", "Right", None, QtGui.QApplication.UnicodeUTF8))
        self.lb_TF_AddTicks.setText(QtGui.QApplication.translate("DlgViewPrms", "Add Ticks : ", None, QtGui.QApplication.UnicodeUTF8))
        self.lb_TF_TicksColor.setText(QtGui.QApplication.translate("DlgViewPrms", "Ticks Color :", None, QtGui.QApplication.UnicodeUTF8))
        self.cb_TF_TicksColor.setItemText(0, QtGui.QApplication.translate("DlgViewPrms", "Black", None, QtGui.QApplication.UnicodeUTF8))
        self.cb_TF_TicksColor.setItemText(1, QtGui.QApplication.translate("DlgViewPrms", "White", None, QtGui.QApplication.UnicodeUTF8))
        self.lb_TF_MajorTicks.setText(QtGui.QApplication.translate("DlgViewPrms", "Major Ticks", None, QtGui.QApplication.UnicodeUTF8))
        self.lb_TF_MajorTicks_L.setText(QtGui.QApplication.translate("DlgViewPrms", "Length :", None, QtGui.QApplication.UnicodeUTF8))
        self.lb_TF_MajorTicks_W.setText(QtGui.QApplication.translate("DlgViewPrms", "Width :", None, QtGui.QApplication.UnicodeUTF8))
        self.ch_TF_MinorTicks.setText(QtGui.QApplication.translate("DlgViewPrms", "Minor Ticks", None, QtGui.QApplication.UnicodeUTF8))
        self.lb_TF_MinorTicks_L.setText(QtGui.QApplication.translate("DlgViewPrms", "Length :", None, QtGui.QApplication.UnicodeUTF8))
        self.lb_TF_MinorTicks_W.setText(QtGui.QApplication.translate("DlgViewPrms", "Width :", None, QtGui.QApplication.UnicodeUTF8))
        self.lb_TF_FrameLine_W.setText(QtGui.QApplication.translate("DlgViewPrms", "Frame Line Width :", None, QtGui.QApplication.UnicodeUTF8))
        self.ch_TF_BottomSideTicks.setText(QtGui.QApplication.translate("DlgViewPrms", "Bottom", None, QtGui.QApplication.UnicodeUTF8))
        self.ch_TF_LeftSideTicks.setText(QtGui.QApplication.translate("DlgViewPrms", "Left", None, QtGui.QApplication.UnicodeUTF8))
        self.tabWidget_2.setTabText(self.tabWidget_2.indexOf(self.tab_6), QtGui.QApplication.translate("DlgViewPrms", "Ticks-Frame", None, QtGui.QApplication.UnicodeUTF8))
        self.txt_fs_y.setText(QtGui.QApplication.translate("DlgViewPrms", "9", None, QtGui.QApplication.UnicodeUTF8))
        self.label_50.setText(QtGui.QApplication.translate("DlgViewPrms", "Type", None, QtGui.QApplication.UnicodeUTF8))
        self.label_48.setText(QtGui.QApplication.translate("DlgViewPrms", "Title", None, QtGui.QApplication.UnicodeUTF8))
        self.txt_fs_title.setText(QtGui.QApplication.translate("DlgViewPrms", "10", None, QtGui.QApplication.UnicodeUTF8))
        self.txt_fs_x.setText(QtGui.QApplication.translate("DlgViewPrms", "9", None, QtGui.QApplication.UnicodeUTF8))
        self.txt_fs_comment.setText(QtGui.QApplication.translate("DlgViewPrms", "8", None, QtGui.QApplication.UnicodeUTF8))
        self.label_49.setText(QtGui.QApplication.translate("DlgViewPrms", "Size", None, QtGui.QApplication.UnicodeUTF8))
        self.label_17.setText(QtGui.QApplication.translate("DlgViewPrms", "Comment", None, QtGui.QApplication.UnicodeUTF8))
        self.txt_fs_xticks.setText(QtGui.QApplication.translate("DlgViewPrms", "8", None, QtGui.QApplication.UnicodeUTF8))
        self.txt_fs_yticks.setText(QtGui.QApplication.translate("DlgViewPrms", "8", None, QtGui.QApplication.UnicodeUTF8))
        self.label_37.setText(QtGui.QApplication.translate("DlgViewPrms", "X Label", None, QtGui.QApplication.UnicodeUTF8))
        self.label_38.setText(QtGui.QApplication.translate("DlgViewPrms", "Y Label", None, QtGui.QApplication.UnicodeUTF8))
        self.label_39.setText(QtGui.QApplication.translate("DlgViewPrms", "X Ticks Label", None, QtGui.QApplication.UnicodeUTF8))
        self.label_40.setText(QtGui.QApplication.translate("DlgViewPrms", "Y Ticks Label", None, QtGui.QApplication.UnicodeUTF8))
        self.label_41.setText(QtGui.QApplication.translate("DlgViewPrms", "Colorbar Ticks Label", None, QtGui.QApplication.UnicodeUTF8))
        self.txt_fs_cbticks.setText(QtGui.QApplication.translate("DlgViewPrms", "8", None, QtGui.QApplication.UnicodeUTF8))
        self.tabWidget_2.setTabText(self.tabWidget_2.indexOf(self.tab_7), QtGui.QApplication.translate("DlgViewPrms", "Font", None, QtGui.QApplication.UnicodeUTF8))
        self.btn_close.setText(QtGui.QApplication.translate("DlgViewPrms", "Close", None, QtGui.QApplication.UnicodeUTF8))
        self.btn_apply.setText(QtGui.QApplication.translate("DlgViewPrms", "Apply", None, QtGui.QApplication.UnicodeUTF8))
        self.btn_backToInitial.setText(QtGui.QApplication.translate("DlgViewPrms", "Initial", None, QtGui.QApplication.UnicodeUTF8))
        self.btn_backToDefault.setText(QtGui.QApplication.translate("DlgViewPrms", "Default", None, QtGui.QApplication.UnicodeUTF8))
        self.btn_saveAsDefault.setText(QtGui.QApplication.translate("DlgViewPrms", "Default", None, QtGui.QApplication.UnicodeUTF8))
        self.label_29.setText(QtGui.QApplication.translate("DlgViewPrms", "Back to :", None, QtGui.QApplication.UnicodeUTF8))
        self.label_30.setText(QtGui.QApplication.translate("DlgViewPrms", "Save as :", None, QtGui.QApplication.UnicodeUTF8))

